# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class Series(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'name': 'str',
        'is_color_varied': 'bool',
        'inverted_solid_fill_color': 'str',
        'smooth': 'bool',
        'plot_on_second_axis': 'bool',
        'order': 'int',
        'number_format_of_y_values': 'str',
        'number_format_of_x_values': 'str',
        'number_format_of_values': 'str',
        'number_format_of_bubble_sizes': 'str',
        'invert_if_negative': 'bool',
        'explosion': 'int',
        'marker': 'SeriesMarker',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat'
    }

    attribute_map = {
        'type': 'type',
        'name': 'name',
        'is_color_varied': 'isColorVaried',
        'inverted_solid_fill_color': 'invertedSolidFillColor',
        'smooth': 'smooth',
        'plot_on_second_axis': 'plotOnSecondAxis',
        'order': 'order',
        'number_format_of_y_values': 'numberFormatOfYValues',
        'number_format_of_x_values': 'numberFormatOfXValues',
        'number_format_of_values': 'numberFormatOfValues',
        'number_format_of_bubble_sizes': 'numberFormatOfBubbleSizes',
        'invert_if_negative': 'invertIfNegative',
        'explosion': 'explosion',
        'marker': 'marker',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat'
    }

    type_determiners = {
    }

    def __init__(self, type=None, name=None, is_color_varied=None, inverted_solid_fill_color=None, smooth=None, plot_on_second_axis=None, order=None, number_format_of_y_values=None, number_format_of_x_values=None, number_format_of_values=None, number_format_of_bubble_sizes=None, invert_if_negative=None, explosion=None, marker=None, fill_format=None, effect_format=None, line_format=None):  # noqa: E501
        """Series - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._name = None
        self._is_color_varied = None
        self._inverted_solid_fill_color = None
        self._smooth = None
        self._plot_on_second_axis = None
        self._order = None
        self._number_format_of_y_values = None
        self._number_format_of_x_values = None
        self._number_format_of_values = None
        self._number_format_of_bubble_sizes = None
        self._invert_if_negative = None
        self._explosion = None
        self._marker = None
        self._fill_format = None
        self._effect_format = None
        self._line_format = None

        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if is_color_varied is not None:
            self.is_color_varied = is_color_varied
        if inverted_solid_fill_color is not None:
            self.inverted_solid_fill_color = inverted_solid_fill_color
        if smooth is not None:
            self.smooth = smooth
        if plot_on_second_axis is not None:
            self.plot_on_second_axis = plot_on_second_axis
        if order is not None:
            self.order = order
        if number_format_of_y_values is not None:
            self.number_format_of_y_values = number_format_of_y_values
        if number_format_of_x_values is not None:
            self.number_format_of_x_values = number_format_of_x_values
        if number_format_of_values is not None:
            self.number_format_of_values = number_format_of_values
        if number_format_of_bubble_sizes is not None:
            self.number_format_of_bubble_sizes = number_format_of_bubble_sizes
        if invert_if_negative is not None:
            self.invert_if_negative = invert_if_negative
        if explosion is not None:
            self.explosion = explosion
        if marker is not None:
            self.marker = marker
        if fill_format is not None:
            self.fill_format = fill_format
        if effect_format is not None:
            self.effect_format = effect_format
        if line_format is not None:
            self.line_format = line_format

    @property
    def type(self):
        """Gets the type of this Series.  # noqa: E501

        Series type.  # noqa: E501

        :return: The type of this Series.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Series.

        Series type.  # noqa: E501

        :param type: The type of this Series.  # noqa: E501
        :type: str
        """
        if type is not None:
            allowed_values = ["ClusteredColumn", "StackedColumn", "PercentsStackedColumn", "ClusteredColumn3D", "StackedColumn3D", "PercentsStackedColumn3D", "Column3D", "ClusteredCylinder", "StackedCylinder", "PercentsStackedCylinder", "Cylinder3D", "ClusteredCone", "StackedCone", "PercentsStackedCone", "Cone3D", "ClusteredPyramid", "StackedPyramid", "PercentsStackedPyramid", "Pyramid3D", "Line", "StackedLine", "PercentsStackedLine", "LineWithMarkers", "StackedLineWithMarkers", "PercentsStackedLineWithMarkers", "Line3D", "Pie", "Pie3D", "PieOfPie", "ExplodedPie", "ExplodedPie3D", "BarOfPie", "PercentsStackedBar", "ClusteredBar3D", "ClusteredBar", "StackedBar", "StackedBar3D", "PercentsStackedBar3D", "ClusteredHorizontalCylinder", "StackedHorizontalCylinder", "PercentsStackedHorizontalCylinder", "ClusteredHorizontalCone", "StackedHorizontalCone", "PercentsStackedHorizontalCone", "ClusteredHorizontalPyramid", "StackedHorizontalPyramid", "PercentsStackedHorizontalPyramid", "Area", "StackedArea", "PercentsStackedArea", "Area3D", "StackedArea3D", "PercentsStackedArea3D", "ScatterWithMarkers", "ScatterWithSmoothLinesAndMarkers", "ScatterWithSmoothLines", "ScatterWithStraightLinesAndMarkers", "ScatterWithStraightLines", "HighLowClose", "OpenHighLowClose", "VolumeHighLowClose", "VolumeOpenHighLowClose", "Surface3D", "WireframeSurface3D", "Contour", "WireframeContour", "Doughnut", "ExplodedDoughnut", "Bubble", "BubbleWith3D", "Radar", "RadarWithMarkers", "FilledRadar", "SeriesOfMixedTypes", "Treemap", "Sunburst", "Histogram", "ParetoLine", "BoxAndWhisker", "Waterfall", "Funnel"]  # noqa: E501
            if type.isdigit():
                int_type = int(type)
                if int_type < 0 or int_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                        .format(type, allowed_values)
                    )
                self._type = allowed_values[int_type]
                return
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values)
                )
        self._type = type

    @property
    def name(self):
        """Gets the name of this Series.  # noqa: E501

        Series name.  # noqa: E501

        :return: The name of this Series.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Series.

        Series name.  # noqa: E501

        :param name: The name of this Series.  # noqa: E501
        :type: str
        """
        self._name = name

    @property
    def is_color_varied(self):
        """Gets the is_color_varied of this Series.  # noqa: E501

        True if each data marker in the series has a different color.  # noqa: E501

        :return: The is_color_varied of this Series.  # noqa: E501
        :rtype: bool
        """
        return self._is_color_varied

    @is_color_varied.setter
    def is_color_varied(self, is_color_varied):
        """Sets the is_color_varied of this Series.

        True if each data marker in the series has a different color.  # noqa: E501

        :param is_color_varied: The is_color_varied of this Series.  # noqa: E501
        :type: bool
        """
        self._is_color_varied = is_color_varied

    @property
    def inverted_solid_fill_color(self):
        """Gets the inverted_solid_fill_color of this Series.  # noqa: E501

        Invert solid color for the series.  # noqa: E501

        :return: The inverted_solid_fill_color of this Series.  # noqa: E501
        :rtype: str
        """
        return self._inverted_solid_fill_color

    @inverted_solid_fill_color.setter
    def inverted_solid_fill_color(self, inverted_solid_fill_color):
        """Sets the inverted_solid_fill_color of this Series.

        Invert solid color for the series.  # noqa: E501

        :param inverted_solid_fill_color: The inverted_solid_fill_color of this Series.  # noqa: E501
        :type: str
        """
        self._inverted_solid_fill_color = inverted_solid_fill_color

    @property
    def smooth(self):
        """Gets the smooth of this Series.  # noqa: E501

        True if curve smoothing is turned on. Applies only to line and scatter connected by lines charts.  # noqa: E501

        :return: The smooth of this Series.  # noqa: E501
        :rtype: bool
        """
        return self._smooth

    @smooth.setter
    def smooth(self, smooth):
        """Sets the smooth of this Series.

        True if curve smoothing is turned on. Applies only to line and scatter connected by lines charts.  # noqa: E501

        :param smooth: The smooth of this Series.  # noqa: E501
        :type: bool
        """
        self._smooth = smooth

    @property
    def plot_on_second_axis(self):
        """Gets the plot_on_second_axis of this Series.  # noqa: E501

        True if the series is plotted on second value axis.  # noqa: E501

        :return: The plot_on_second_axis of this Series.  # noqa: E501
        :rtype: bool
        """
        return self._plot_on_second_axis

    @plot_on_second_axis.setter
    def plot_on_second_axis(self, plot_on_second_axis):
        """Sets the plot_on_second_axis of this Series.

        True if the series is plotted on second value axis.  # noqa: E501

        :param plot_on_second_axis: The plot_on_second_axis of this Series.  # noqa: E501
        :type: bool
        """
        self._plot_on_second_axis = plot_on_second_axis

    @property
    def order(self):
        """Gets the order of this Series.  # noqa: E501

        Series order.  # noqa: E501

        :return: The order of this Series.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Series.

        Series order.  # noqa: E501

        :param order: The order of this Series.  # noqa: E501
        :type: int
        """
        self._order = order

    @property
    def number_format_of_y_values(self):
        """Gets the number_format_of_y_values of this Series.  # noqa: E501

        The number format for the series y values.  # noqa: E501

        :return: The number_format_of_y_values of this Series.  # noqa: E501
        :rtype: str
        """
        return self._number_format_of_y_values

    @number_format_of_y_values.setter
    def number_format_of_y_values(self, number_format_of_y_values):
        """Sets the number_format_of_y_values of this Series.

        The number format for the series y values.  # noqa: E501

        :param number_format_of_y_values: The number_format_of_y_values of this Series.  # noqa: E501
        :type: str
        """
        self._number_format_of_y_values = number_format_of_y_values

    @property
    def number_format_of_x_values(self):
        """Gets the number_format_of_x_values of this Series.  # noqa: E501

        The number format for the series x values.  # noqa: E501

        :return: The number_format_of_x_values of this Series.  # noqa: E501
        :rtype: str
        """
        return self._number_format_of_x_values

    @number_format_of_x_values.setter
    def number_format_of_x_values(self, number_format_of_x_values):
        """Sets the number_format_of_x_values of this Series.

        The number format for the series x values.  # noqa: E501

        :param number_format_of_x_values: The number_format_of_x_values of this Series.  # noqa: E501
        :type: str
        """
        self._number_format_of_x_values = number_format_of_x_values

    @property
    def number_format_of_values(self):
        """Gets the number_format_of_values of this Series.  # noqa: E501

        The number format for the series values.  # noqa: E501

        :return: The number_format_of_values of this Series.  # noqa: E501
        :rtype: str
        """
        return self._number_format_of_values

    @number_format_of_values.setter
    def number_format_of_values(self, number_format_of_values):
        """Sets the number_format_of_values of this Series.

        The number format for the series values.  # noqa: E501

        :param number_format_of_values: The number_format_of_values of this Series.  # noqa: E501
        :type: str
        """
        self._number_format_of_values = number_format_of_values

    @property
    def number_format_of_bubble_sizes(self):
        """Gets the number_format_of_bubble_sizes of this Series.  # noqa: E501

        The number format for the series bubble sizes.  # noqa: E501

        :return: The number_format_of_bubble_sizes of this Series.  # noqa: E501
        :rtype: str
        """
        return self._number_format_of_bubble_sizes

    @number_format_of_bubble_sizes.setter
    def number_format_of_bubble_sizes(self, number_format_of_bubble_sizes):
        """Sets the number_format_of_bubble_sizes of this Series.

        The number format for the series bubble sizes.  # noqa: E501

        :param number_format_of_bubble_sizes: The number_format_of_bubble_sizes of this Series.  # noqa: E501
        :type: str
        """
        self._number_format_of_bubble_sizes = number_format_of_bubble_sizes

    @property
    def invert_if_negative(self):
        """Gets the invert_if_negative of this Series.  # noqa: E501

        True if the series shall invert its colors if the value is negative. Applies to bar, column and bubble series.  # noqa: E501

        :return: The invert_if_negative of this Series.  # noqa: E501
        :rtype: bool
        """
        return self._invert_if_negative

    @invert_if_negative.setter
    def invert_if_negative(self, invert_if_negative):
        """Sets the invert_if_negative of this Series.

        True if the series shall invert its colors if the value is negative. Applies to bar, column and bubble series.  # noqa: E501

        :param invert_if_negative: The invert_if_negative of this Series.  # noqa: E501
        :type: bool
        """
        self._invert_if_negative = invert_if_negative

    @property
    def explosion(self):
        """Gets the explosion of this Series.  # noqa: E501

        The distance of an open pie slice from the center of the pie chart is expressed as a percentage of the pie diameter.  # noqa: E501

        :return: The explosion of this Series.  # noqa: E501
        :rtype: int
        """
        return self._explosion

    @explosion.setter
    def explosion(self, explosion):
        """Sets the explosion of this Series.

        The distance of an open pie slice from the center of the pie chart is expressed as a percentage of the pie diameter.  # noqa: E501

        :param explosion: The explosion of this Series.  # noqa: E501
        :type: int
        """
        self._explosion = explosion

    @property
    def marker(self):
        """Gets the marker of this Series.  # noqa: E501

        Series marker.  # noqa: E501

        :return: The marker of this Series.  # noqa: E501
        :rtype: SeriesMarker
        """
        return self._marker

    @marker.setter
    def marker(self, marker):
        """Sets the marker of this Series.

        Series marker.  # noqa: E501

        :param marker: The marker of this Series.  # noqa: E501
        :type: SeriesMarker
        """
        self._marker = marker

    @property
    def fill_format(self):
        """Gets the fill_format of this Series.  # noqa: E501

        Fill properties set for the series.  # noqa: E501

        :return: The fill_format of this Series.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this Series.

        Fill properties set for the series.  # noqa: E501

        :param fill_format: The fill_format of this Series.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def effect_format(self):
        """Gets the effect_format of this Series.  # noqa: E501

        Effect properties set for the series.  # noqa: E501

        :return: The effect_format of this Series.  # noqa: E501
        :rtype: EffectFormat
        """
        return self._effect_format

    @effect_format.setter
    def effect_format(self, effect_format):
        """Sets the effect_format of this Series.

        Effect properties set for the series.  # noqa: E501

        :param effect_format: The effect_format of this Series.  # noqa: E501
        :type: EffectFormat
        """
        self._effect_format = effect_format

    @property
    def line_format(self):
        """Gets the line_format of this Series.  # noqa: E501

        Line properties set for the series.  # noqa: E501

        :return: The line_format of this Series.  # noqa: E501
        :rtype: LineFormat
        """
        return self._line_format

    @line_format.setter
    def line_format(self, line_format):
        """Sets the line_format of this Series.

        Line properties set for the series.  # noqa: E501

        :param line_format: The line_format of this Series.  # noqa: E501
        :type: LineFormat
        """
        self._line_format = line_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Series):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class EffectFormat(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'blur': 'BlurEffect',
        'glow': 'GlowEffect',
        'inner_shadow': 'InnerShadowEffect',
        'outer_shadow': 'OuterShadowEffect',
        'preset_shadow': 'PresetShadowEffect',
        'soft_edge': 'SoftEdgeEffect',
        'reflection': 'ReflectionEffect',
        'fill_overlay': 'FillOverlayEffect'
    }

    attribute_map = {
        'blur': 'blur',
        'glow': 'glow',
        'inner_shadow': 'innerShadow',
        'outer_shadow': 'outerShadow',
        'preset_shadow': 'presetShadow',
        'soft_edge': 'softEdge',
        'reflection': 'reflection',
        'fill_overlay': 'fillOverlay'
    }

    type_determiners = {
    }

    def __init__(self, blur=None, glow=None, inner_shadow=None, outer_shadow=None, preset_shadow=None, soft_edge=None, reflection=None, fill_overlay=None):  # noqa: E501
        """EffectFormat - a model defined in Swagger"""  # noqa: E501

        self._blur = None
        self._glow = None
        self._inner_shadow = None
        self._outer_shadow = None
        self._preset_shadow = None
        self._soft_edge = None
        self._reflection = None
        self._fill_overlay = None

        if blur is not None:
            self.blur = blur
        if glow is not None:
            self.glow = glow
        if inner_shadow is not None:
            self.inner_shadow = inner_shadow
        if outer_shadow is not None:
            self.outer_shadow = outer_shadow
        if preset_shadow is not None:
            self.preset_shadow = preset_shadow
        if soft_edge is not None:
            self.soft_edge = soft_edge
        if reflection is not None:
            self.reflection = reflection
        if fill_overlay is not None:
            self.fill_overlay = fill_overlay

    @property
    def blur(self):
        """Gets the blur of this EffectFormat.  # noqa: E501

        blur effect  # noqa: E501

        :return: The blur of this EffectFormat.  # noqa: E501
        :rtype: BlurEffect
        """
        return self._blur

    @blur.setter
    def blur(self, blur):
        """Sets the blur of this EffectFormat.

        blur effect  # noqa: E501

        :param blur: The blur of this EffectFormat.  # noqa: E501
        :type: BlurEffect
        """
        self._blur = blur

    @property
    def glow(self):
        """Gets the glow of this EffectFormat.  # noqa: E501

        glow effect  # noqa: E501

        :return: The glow of this EffectFormat.  # noqa: E501
        :rtype: GlowEffect
        """
        return self._glow

    @glow.setter
    def glow(self, glow):
        """Sets the glow of this EffectFormat.

        glow effect  # noqa: E501

        :param glow: The glow of this EffectFormat.  # noqa: E501
        :type: GlowEffect
        """
        self._glow = glow

    @property
    def inner_shadow(self):
        """Gets the inner_shadow of this EffectFormat.  # noqa: E501

        inner shadow effect  # noqa: E501

        :return: The inner_shadow of this EffectFormat.  # noqa: E501
        :rtype: InnerShadowEffect
        """
        return self._inner_shadow

    @inner_shadow.setter
    def inner_shadow(self, inner_shadow):
        """Sets the inner_shadow of this EffectFormat.

        inner shadow effect  # noqa: E501

        :param inner_shadow: The inner_shadow of this EffectFormat.  # noqa: E501
        :type: InnerShadowEffect
        """
        self._inner_shadow = inner_shadow

    @property
    def outer_shadow(self):
        """Gets the outer_shadow of this EffectFormat.  # noqa: E501

        outer shadow effect  # noqa: E501

        :return: The outer_shadow of this EffectFormat.  # noqa: E501
        :rtype: OuterShadowEffect
        """
        return self._outer_shadow

    @outer_shadow.setter
    def outer_shadow(self, outer_shadow):
        """Sets the outer_shadow of this EffectFormat.

        outer shadow effect  # noqa: E501

        :param outer_shadow: The outer_shadow of this EffectFormat.  # noqa: E501
        :type: OuterShadowEffect
        """
        self._outer_shadow = outer_shadow

    @property
    def preset_shadow(self):
        """Gets the preset_shadow of this EffectFormat.  # noqa: E501

        preset shadow effect  # noqa: E501

        :return: The preset_shadow of this EffectFormat.  # noqa: E501
        :rtype: PresetShadowEffect
        """
        return self._preset_shadow

    @preset_shadow.setter
    def preset_shadow(self, preset_shadow):
        """Sets the preset_shadow of this EffectFormat.

        preset shadow effect  # noqa: E501

        :param preset_shadow: The preset_shadow of this EffectFormat.  # noqa: E501
        :type: PresetShadowEffect
        """
        self._preset_shadow = preset_shadow

    @property
    def soft_edge(self):
        """Gets the soft_edge of this EffectFormat.  # noqa: E501

        soft edge effect  # noqa: E501

        :return: The soft_edge of this EffectFormat.  # noqa: E501
        :rtype: SoftEdgeEffect
        """
        return self._soft_edge

    @soft_edge.setter
    def soft_edge(self, soft_edge):
        """Sets the soft_edge of this EffectFormat.

        soft edge effect  # noqa: E501

        :param soft_edge: The soft_edge of this EffectFormat.  # noqa: E501
        :type: SoftEdgeEffect
        """
        self._soft_edge = soft_edge

    @property
    def reflection(self):
        """Gets the reflection of this EffectFormat.  # noqa: E501

        reflection effect  # noqa: E501

        :return: The reflection of this EffectFormat.  # noqa: E501
        :rtype: ReflectionEffect
        """
        return self._reflection

    @reflection.setter
    def reflection(self, reflection):
        """Sets the reflection of this EffectFormat.

        reflection effect  # noqa: E501

        :param reflection: The reflection of this EffectFormat.  # noqa: E501
        :type: ReflectionEffect
        """
        self._reflection = reflection

    @property
    def fill_overlay(self):
        """Gets the fill_overlay of this EffectFormat.  # noqa: E501

        fill overlay effect  # noqa: E501

        :return: The fill_overlay of this EffectFormat.  # noqa: E501
        :rtype: FillOverlayEffect
        """
        return self._fill_overlay

    @fill_overlay.setter
    def fill_overlay(self, fill_overlay):
        """Sets the fill_overlay of this EffectFormat.

        fill overlay effect  # noqa: E501

        :param fill_overlay: The fill_overlay of this EffectFormat.  # noqa: E501
        :type: FillOverlayEffect
        """
        self._fill_overlay = fill_overlay

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EffectFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
# apiPackage asposeslidescloud.apis
# apiPackage 
from asposeslidescloud.apis.api_base import ApiBase
from asposeslidescloud.apis.slides_api import SlidesApi



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.fill_format import FillFormat

class PictureFill(FillFormat):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'crop_bottom': 'float',
        'crop_left': 'float',
        'crop_right': 'float',
        'crop_top': 'float',
        'dpi': 'int',
        'image': 'ResourceUriElement',
        'base64_data': 'str',
        'svg_data': 'str',
        'picture_fill_mode': 'str'
    }

    attribute_map = {
        'type': 'type',
        'crop_bottom': 'cropBottom',
        'crop_left': 'cropLeft',
        'crop_right': 'cropRight',
        'crop_top': 'cropTop',
        'dpi': 'dpi',
        'image': 'image',
        'base64_data': 'base64Data',
        'svg_data': 'svgData',
        'picture_fill_mode': 'pictureFillMode'
    }

    type_determiners = {
        'type': 'Picture',
    }

    def __init__(self, type='Picture', crop_bottom=None, crop_left=None, crop_right=None, crop_top=None, dpi=None, image=None, base64_data=None, svg_data=None, picture_fill_mode=None):  # noqa: E501
        """PictureFill - a model defined in Swagger"""  # noqa: E501
        super(PictureFill, self).__init__(type)

        self._crop_bottom = None
        self._crop_left = None
        self._crop_right = None
        self._crop_top = None
        self._dpi = None
        self._image = None
        self._base64_data = None
        self._svg_data = None
        self._picture_fill_mode = None
        self.type: 'Picture'

        self.crop_bottom = crop_bottom
        self.crop_left = crop_left
        self.crop_right = crop_right
        self.crop_top = crop_top
        self.dpi = dpi
        if image is not None:
            self.image = image
        if base64_data is not None:
            self.base64_data = base64_data
        if svg_data is not None:
            self.svg_data = svg_data
        self.picture_fill_mode = picture_fill_mode

    @property
    def crop_bottom(self):
        """Gets the crop_bottom of this PictureFill.  # noqa: E501

        Percentage of image height that is cropped from the bottom.  # noqa: E501

        :return: The crop_bottom of this PictureFill.  # noqa: E501
        :rtype: float
        """
        return self._crop_bottom

    @crop_bottom.setter
    def crop_bottom(self, crop_bottom):
        """Sets the crop_bottom of this PictureFill.

        Percentage of image height that is cropped from the bottom.  # noqa: E501

        :param crop_bottom: The crop_bottom of this PictureFill.  # noqa: E501
        :type: float
        """
        self._crop_bottom = crop_bottom

    @property
    def crop_left(self):
        """Gets the crop_left of this PictureFill.  # noqa: E501

        Percentage of image height that is cropped from the left.  # noqa: E501

        :return: The crop_left of this PictureFill.  # noqa: E501
        :rtype: float
        """
        return self._crop_left

    @crop_left.setter
    def crop_left(self, crop_left):
        """Sets the crop_left of this PictureFill.

        Percentage of image height that is cropped from the left.  # noqa: E501

        :param crop_left: The crop_left of this PictureFill.  # noqa: E501
        :type: float
        """
        self._crop_left = crop_left

    @property
    def crop_right(self):
        """Gets the crop_right of this PictureFill.  # noqa: E501

        Percentage of image height that is cropped from the right.  # noqa: E501

        :return: The crop_right of this PictureFill.  # noqa: E501
        :rtype: float
        """
        return self._crop_right

    @crop_right.setter
    def crop_right(self, crop_right):
        """Sets the crop_right of this PictureFill.

        Percentage of image height that is cropped from the right.  # noqa: E501

        :param crop_right: The crop_right of this PictureFill.  # noqa: E501
        :type: float
        """
        self._crop_right = crop_right

    @property
    def crop_top(self):
        """Gets the crop_top of this PictureFill.  # noqa: E501

        Percentage of image height that is cropped from the top.  # noqa: E501

        :return: The crop_top of this PictureFill.  # noqa: E501
        :rtype: float
        """
        return self._crop_top

    @crop_top.setter
    def crop_top(self, crop_top):
        """Sets the crop_top of this PictureFill.

        Percentage of image height that is cropped from the top.  # noqa: E501

        :param crop_top: The crop_top of this PictureFill.  # noqa: E501
        :type: float
        """
        self._crop_top = crop_top

    @property
    def dpi(self):
        """Gets the dpi of this PictureFill.  # noqa: E501

        Picture resolution.  # noqa: E501

        :return: The dpi of this PictureFill.  # noqa: E501
        :rtype: int
        """
        return self._dpi

    @dpi.setter
    def dpi(self, dpi):
        """Sets the dpi of this PictureFill.

        Picture resolution.  # noqa: E501

        :param dpi: The dpi of this PictureFill.  # noqa: E501
        :type: int
        """
        self._dpi = dpi

    @property
    def image(self):
        """Gets the image of this PictureFill.  # noqa: E501

        Internal image link.  # noqa: E501

        :return: The image of this PictureFill.  # noqa: E501
        :rtype: ResourceUriElement
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this PictureFill.

        Internal image link.  # noqa: E501

        :param image: The image of this PictureFill.  # noqa: E501
        :type: ResourceUriElement
        """
        self._image = image

    @property
    def base64_data(self):
        """Gets the base64_data of this PictureFill.  # noqa: E501

        Base 64 image data.  # noqa: E501

        :return: The base64_data of this PictureFill.  # noqa: E501
        :rtype: str
        """
        return self._base64_data

    @base64_data.setter
    def base64_data(self, base64_data):
        """Sets the base64_data of this PictureFill.

        Base 64 image data.  # noqa: E501

        :param base64_data: The base64_data of this PictureFill.  # noqa: E501
        :type: str
        """
        self._base64_data = base64_data

    @property
    def svg_data(self):
        """Gets the svg_data of this PictureFill.  # noqa: E501

        SVG image data.  # noqa: E501

        :return: The svg_data of this PictureFill.  # noqa: E501
        :rtype: str
        """
        return self._svg_data

    @svg_data.setter
    def svg_data(self, svg_data):
        """Sets the svg_data of this PictureFill.

        SVG image data.  # noqa: E501

        :param svg_data: The svg_data of this PictureFill.  # noqa: E501
        :type: str
        """
        self._svg_data = svg_data

    @property
    def picture_fill_mode(self):
        """Gets the picture_fill_mode of this PictureFill.  # noqa: E501

        Fill mode.  # noqa: E501

        :return: The picture_fill_mode of this PictureFill.  # noqa: E501
        :rtype: str
        """
        return self._picture_fill_mode

    @picture_fill_mode.setter
    def picture_fill_mode(self, picture_fill_mode):
        """Sets the picture_fill_mode of this PictureFill.

        Fill mode.  # noqa: E501

        :param picture_fill_mode: The picture_fill_mode of this PictureFill.  # noqa: E501
        :type: str
        """
        if picture_fill_mode is not None:
            allowed_values = ["Tile", "Stretch"]  # noqa: E501
            if picture_fill_mode.isdigit():
                int_picture_fill_mode = int(picture_fill_mode)
                if int_picture_fill_mode < 0 or int_picture_fill_mode >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `picture_fill_mode` ({0}), must be one of {1}"  # noqa: E501
                        .format(picture_fill_mode, allowed_values)
                    )
                self._picture_fill_mode = allowed_values[int_picture_fill_mode]
                return
            if picture_fill_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `picture_fill_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(picture_fill_mode, allowed_values)
                )
        self._picture_fill_mode = picture_fill_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PictureFill):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.resource_base import ResourceBase

class Paragraph(ResourceBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'margin_left': 'float',
        'margin_right': 'float',
        'space_before': 'float',
        'space_after': 'float',
        'space_within': 'float',
        'indent': 'float',
        'alignment': 'str',
        'font_alignment': 'str',
        'default_tab_size': 'float',
        'depth': 'int',
        'bullet_char': 'str',
        'bullet_height': 'float',
        'bullet_type': 'str',
        'numbered_bullet_start_with': 'int',
        'numbered_bullet_style': 'str',
        'hanging_punctuation': 'str',
        'east_asian_line_break': 'str',
        'latin_line_break': 'str',
        'right_to_left': 'str',
        'portion_list': 'list[ResourceUriElement]'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'margin_left': 'marginLeft',
        'margin_right': 'marginRight',
        'space_before': 'spaceBefore',
        'space_after': 'spaceAfter',
        'space_within': 'spaceWithin',
        'indent': 'indent',
        'alignment': 'alignment',
        'font_alignment': 'fontAlignment',
        'default_tab_size': 'defaultTabSize',
        'depth': 'depth',
        'bullet_char': 'bulletChar',
        'bullet_height': 'bulletHeight',
        'bullet_type': 'bulletType',
        'numbered_bullet_start_with': 'numberedBulletStartWith',
        'numbered_bullet_style': 'numberedBulletStyle',
        'hanging_punctuation': 'hangingPunctuation',
        'east_asian_line_break': 'eastAsianLineBreak',
        'latin_line_break': 'latinLineBreak',
        'right_to_left': 'rightToLeft',
        'portion_list': 'portionList'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, margin_left=None, margin_right=None, space_before=None, space_after=None, space_within=None, indent=None, alignment=None, font_alignment=None, default_tab_size=None, depth=None, bullet_char=None, bullet_height=None, bullet_type=None, numbered_bullet_start_with=None, numbered_bullet_style=None, hanging_punctuation=None, east_asian_line_break=None, latin_line_break=None, right_to_left=None, portion_list=None):  # noqa: E501
        """Paragraph - a model defined in Swagger"""  # noqa: E501
        super(Paragraph, self).__init__(self_uri, alternate_links)

        self._margin_left = None
        self._margin_right = None
        self._space_before = None
        self._space_after = None
        self._space_within = None
        self._indent = None
        self._alignment = None
        self._font_alignment = None
        self._default_tab_size = None
        self._depth = None
        self._bullet_char = None
        self._bullet_height = None
        self._bullet_type = None
        self._numbered_bullet_start_with = None
        self._numbered_bullet_style = None
        self._hanging_punctuation = None
        self._east_asian_line_break = None
        self._latin_line_break = None
        self._right_to_left = None
        self._portion_list = None

        if margin_left is not None:
            self.margin_left = margin_left
        if margin_right is not None:
            self.margin_right = margin_right
        if space_before is not None:
            self.space_before = space_before
        if space_after is not None:
            self.space_after = space_after
        if space_within is not None:
            self.space_within = space_within
        if indent is not None:
            self.indent = indent
        if alignment is not None:
            self.alignment = alignment
        if font_alignment is not None:
            self.font_alignment = font_alignment
        if default_tab_size is not None:
            self.default_tab_size = default_tab_size
        if depth is not None:
            self.depth = depth
        if bullet_char is not None:
            self.bullet_char = bullet_char
        if bullet_height is not None:
            self.bullet_height = bullet_height
        if bullet_type is not None:
            self.bullet_type = bullet_type
        if numbered_bullet_start_with is not None:
            self.numbered_bullet_start_with = numbered_bullet_start_with
        if numbered_bullet_style is not None:
            self.numbered_bullet_style = numbered_bullet_style
        if hanging_punctuation is not None:
            self.hanging_punctuation = hanging_punctuation
        if east_asian_line_break is not None:
            self.east_asian_line_break = east_asian_line_break
        if latin_line_break is not None:
            self.latin_line_break = latin_line_break
        if right_to_left is not None:
            self.right_to_left = right_to_left
        if portion_list is not None:
            self.portion_list = portion_list

    @property
    def margin_left(self):
        """Gets the margin_left of this Paragraph.  # noqa: E501

        Left margin.  # noqa: E501

        :return: The margin_left of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._margin_left

    @margin_left.setter
    def margin_left(self, margin_left):
        """Sets the margin_left of this Paragraph.

        Left margin.  # noqa: E501

        :param margin_left: The margin_left of this Paragraph.  # noqa: E501
        :type: float
        """
        self._margin_left = margin_left

    @property
    def margin_right(self):
        """Gets the margin_right of this Paragraph.  # noqa: E501

        Right margin.  # noqa: E501

        :return: The margin_right of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._margin_right

    @margin_right.setter
    def margin_right(self, margin_right):
        """Sets the margin_right of this Paragraph.

        Right margin.  # noqa: E501

        :param margin_right: The margin_right of this Paragraph.  # noqa: E501
        :type: float
        """
        self._margin_right = margin_right

    @property
    def space_before(self):
        """Gets the space_before of this Paragraph.  # noqa: E501

        Left spacing.  # noqa: E501

        :return: The space_before of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._space_before

    @space_before.setter
    def space_before(self, space_before):
        """Sets the space_before of this Paragraph.

        Left spacing.  # noqa: E501

        :param space_before: The space_before of this Paragraph.  # noqa: E501
        :type: float
        """
        self._space_before = space_before

    @property
    def space_after(self):
        """Gets the space_after of this Paragraph.  # noqa: E501

        Right spacing.  # noqa: E501

        :return: The space_after of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._space_after

    @space_after.setter
    def space_after(self, space_after):
        """Sets the space_after of this Paragraph.

        Right spacing.  # noqa: E501

        :param space_after: The space_after of this Paragraph.  # noqa: E501
        :type: float
        """
        self._space_after = space_after

    @property
    def space_within(self):
        """Gets the space_within of this Paragraph.  # noqa: E501

        Spacing between lines.  # noqa: E501

        :return: The space_within of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._space_within

    @space_within.setter
    def space_within(self, space_within):
        """Sets the space_within of this Paragraph.

        Spacing between lines.  # noqa: E501

        :param space_within: The space_within of this Paragraph.  # noqa: E501
        :type: float
        """
        self._space_within = space_within

    @property
    def indent(self):
        """Gets the indent of this Paragraph.  # noqa: E501

        First line indent.  # noqa: E501

        :return: The indent of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._indent

    @indent.setter
    def indent(self, indent):
        """Sets the indent of this Paragraph.

        First line indent.  # noqa: E501

        :param indent: The indent of this Paragraph.  # noqa: E501
        :type: float
        """
        self._indent = indent

    @property
    def alignment(self):
        """Gets the alignment of this Paragraph.  # noqa: E501

        Text alignment.  # noqa: E501

        :return: The alignment of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """Sets the alignment of this Paragraph.

        Text alignment.  # noqa: E501

        :param alignment: The alignment of this Paragraph.  # noqa: E501
        :type: str
        """
        if alignment is not None:
            allowed_values = ["Left", "Center", "Right", "Justify", "JustifyLow", "Distributed", "NotDefined"]  # noqa: E501
            if alignment.isdigit():
                int_alignment = int(alignment)
                if int_alignment < 0 or int_alignment >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                        .format(alignment, allowed_values)
                    )
                self._alignment = allowed_values[int_alignment]
                return
            if alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(alignment, allowed_values)
                )
        self._alignment = alignment

    @property
    def font_alignment(self):
        """Gets the font_alignment of this Paragraph.  # noqa: E501

        Font alignment.  # noqa: E501

        :return: The font_alignment of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._font_alignment

    @font_alignment.setter
    def font_alignment(self, font_alignment):
        """Sets the font_alignment of this Paragraph.

        Font alignment.  # noqa: E501

        :param font_alignment: The font_alignment of this Paragraph.  # noqa: E501
        :type: str
        """
        if font_alignment is not None:
            allowed_values = ["Automatic", "Top", "Center", "Bottom", "Baseline", "Default"]  # noqa: E501
            if font_alignment.isdigit():
                int_font_alignment = int(font_alignment)
                if int_font_alignment < 0 or int_font_alignment >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `font_alignment` ({0}), must be one of {1}"  # noqa: E501
                        .format(font_alignment, allowed_values)
                    )
                self._font_alignment = allowed_values[int_font_alignment]
                return
            if font_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `font_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(font_alignment, allowed_values)
                )
        self._font_alignment = font_alignment

    @property
    def default_tab_size(self):
        """Gets the default_tab_size of this Paragraph.  # noqa: E501

        Default tabulation size.  # noqa: E501

        :return: The default_tab_size of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._default_tab_size

    @default_tab_size.setter
    def default_tab_size(self, default_tab_size):
        """Sets the default_tab_size of this Paragraph.

        Default tabulation size.  # noqa: E501

        :param default_tab_size: The default_tab_size of this Paragraph.  # noqa: E501
        :type: float
        """
        self._default_tab_size = default_tab_size

    @property
    def depth(self):
        """Gets the depth of this Paragraph.  # noqa: E501

        Depth.  # noqa: E501

        :return: The depth of this Paragraph.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this Paragraph.

        Depth.  # noqa: E501

        :param depth: The depth of this Paragraph.  # noqa: E501
        :type: int
        """
        self._depth = depth

    @property
    def bullet_char(self):
        """Gets the bullet_char of this Paragraph.  # noqa: E501

        Bullet char.  # noqa: E501

        :return: The bullet_char of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._bullet_char

    @bullet_char.setter
    def bullet_char(self, bullet_char):
        """Sets the bullet_char of this Paragraph.

        Bullet char.  # noqa: E501

        :param bullet_char: The bullet_char of this Paragraph.  # noqa: E501
        :type: str
        """
        self._bullet_char = bullet_char

    @property
    def bullet_height(self):
        """Gets the bullet_height of this Paragraph.  # noqa: E501

        Bullet height.  # noqa: E501

        :return: The bullet_height of this Paragraph.  # noqa: E501
        :rtype: float
        """
        return self._bullet_height

    @bullet_height.setter
    def bullet_height(self, bullet_height):
        """Sets the bullet_height of this Paragraph.

        Bullet height.  # noqa: E501

        :param bullet_height: The bullet_height of this Paragraph.  # noqa: E501
        :type: float
        """
        self._bullet_height = bullet_height

    @property
    def bullet_type(self):
        """Gets the bullet_type of this Paragraph.  # noqa: E501

        Bullet type.  # noqa: E501

        :return: The bullet_type of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._bullet_type

    @bullet_type.setter
    def bullet_type(self, bullet_type):
        """Sets the bullet_type of this Paragraph.

        Bullet type.  # noqa: E501

        :param bullet_type: The bullet_type of this Paragraph.  # noqa: E501
        :type: str
        """
        if bullet_type is not None:
            allowed_values = ["None", "Symbol", "Numbered", "Picture", "NotDefined"]  # noqa: E501
            if bullet_type.isdigit():
                int_bullet_type = int(bullet_type)
                if int_bullet_type < 0 or int_bullet_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `bullet_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(bullet_type, allowed_values)
                    )
                self._bullet_type = allowed_values[int_bullet_type]
                return
            if bullet_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `bullet_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(bullet_type, allowed_values)
                )
        self._bullet_type = bullet_type

    @property
    def numbered_bullet_start_with(self):
        """Gets the numbered_bullet_start_with of this Paragraph.  # noqa: E501

        Starting number for a numbered bullet.  # noqa: E501

        :return: The numbered_bullet_start_with of this Paragraph.  # noqa: E501
        :rtype: int
        """
        return self._numbered_bullet_start_with

    @numbered_bullet_start_with.setter
    def numbered_bullet_start_with(self, numbered_bullet_start_with):
        """Sets the numbered_bullet_start_with of this Paragraph.

        Starting number for a numbered bullet.  # noqa: E501

        :param numbered_bullet_start_with: The numbered_bullet_start_with of this Paragraph.  # noqa: E501
        :type: int
        """
        self._numbered_bullet_start_with = numbered_bullet_start_with

    @property
    def numbered_bullet_style(self):
        """Gets the numbered_bullet_style of this Paragraph.  # noqa: E501

        Numbered bullet style.  # noqa: E501

        :return: The numbered_bullet_style of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._numbered_bullet_style

    @numbered_bullet_style.setter
    def numbered_bullet_style(self, numbered_bullet_style):
        """Sets the numbered_bullet_style of this Paragraph.

        Numbered bullet style.  # noqa: E501

        :param numbered_bullet_style: The numbered_bullet_style of this Paragraph.  # noqa: E501
        :type: str
        """
        if numbered_bullet_style is not None:
            allowed_values = ["BulletAlphaLCPeriod", "BulletAlphaUCPeriod", "BulletArabicParenRight", "BulletArabicPeriod", "BulletRomanLCParenBoth", "BulletRomanLCParenRight", "BulletRomanLCPeriod", "BulletRomanUCPeriod", "BulletAlphaLCParenBoth", "BulletAlphaLCParenRight", "BulletAlphaUCParenBoth", "BulletAlphaUCParenRight", "BulletArabicParenBoth", "BulletArabicPlain", "BulletRomanUCParenBoth", "BulletRomanUCParenRight", "BulletSimpChinPlain", "BulletSimpChinPeriod", "BulletCircleNumDBPlain", "BulletCircleNumWDWhitePlain", "BulletCircleNumWDBlackPlain", "BulletTradChinPlain", "BulletTradChinPeriod", "BulletArabicAlphaDash", "BulletArabicAbjadDash", "BulletHebrewAlphaDash", "BulletKanjiKoreanPlain", "BulletKanjiKoreanPeriod", "BulletArabicDBPlain", "BulletArabicDBPeriod", "BulletThaiAlphaPeriod", "BulletThaiAlphaParenRight", "BulletThaiAlphaParenBoth", "BulletThaiNumPeriod", "BulletThaiNumParenRight", "BulletThaiNumParenBoth", "BulletHindiAlphaPeriod", "BulletHindiNumPeriod", "BulletKanjiSimpChinDBPeriod", "BulletHindiNumParenRight", "BulletHindiAlpha1Period", "NotDefined"]  # noqa: E501
            if numbered_bullet_style.isdigit():
                int_numbered_bullet_style = int(numbered_bullet_style)
                if int_numbered_bullet_style < 0 or int_numbered_bullet_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `numbered_bullet_style` ({0}), must be one of {1}"  # noqa: E501
                        .format(numbered_bullet_style, allowed_values)
                    )
                self._numbered_bullet_style = allowed_values[int_numbered_bullet_style]
                return
            if numbered_bullet_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `numbered_bullet_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(numbered_bullet_style, allowed_values)
                )
        self._numbered_bullet_style = numbered_bullet_style

    @property
    def hanging_punctuation(self):
        """Gets the hanging_punctuation of this Paragraph.  # noqa: E501

        True if hanging punctuation is used with the paragraph.  # noqa: E501

        :return: The hanging_punctuation of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._hanging_punctuation

    @hanging_punctuation.setter
    def hanging_punctuation(self, hanging_punctuation):
        """Sets the hanging_punctuation of this Paragraph.

        True if hanging punctuation is used with the paragraph.  # noqa: E501

        :param hanging_punctuation: The hanging_punctuation of this Paragraph.  # noqa: E501
        :type: str
        """
        if hanging_punctuation is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if hanging_punctuation.isdigit():
                int_hanging_punctuation = int(hanging_punctuation)
                if int_hanging_punctuation < 0 or int_hanging_punctuation >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `hanging_punctuation` ({0}), must be one of {1}"  # noqa: E501
                        .format(hanging_punctuation, allowed_values)
                    )
                self._hanging_punctuation = allowed_values[int_hanging_punctuation]
                return
            if hanging_punctuation not in allowed_values:
                raise ValueError(
                    "Invalid value for `hanging_punctuation` ({0}), must be one of {1}"  # noqa: E501
                    .format(hanging_punctuation, allowed_values)
                )
        self._hanging_punctuation = hanging_punctuation

    @property
    def east_asian_line_break(self):
        """Gets the east_asian_line_break of this Paragraph.  # noqa: E501

        True if East Asian line break is used with the paragraph.  # noqa: E501

        :return: The east_asian_line_break of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._east_asian_line_break

    @east_asian_line_break.setter
    def east_asian_line_break(self, east_asian_line_break):
        """Sets the east_asian_line_break of this Paragraph.

        True if East Asian line break is used with the paragraph.  # noqa: E501

        :param east_asian_line_break: The east_asian_line_break of this Paragraph.  # noqa: E501
        :type: str
        """
        if east_asian_line_break is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if east_asian_line_break.isdigit():
                int_east_asian_line_break = int(east_asian_line_break)
                if int_east_asian_line_break < 0 or int_east_asian_line_break >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `east_asian_line_break` ({0}), must be one of {1}"  # noqa: E501
                        .format(east_asian_line_break, allowed_values)
                    )
                self._east_asian_line_break = allowed_values[int_east_asian_line_break]
                return
            if east_asian_line_break not in allowed_values:
                raise ValueError(
                    "Invalid value for `east_asian_line_break` ({0}), must be one of {1}"  # noqa: E501
                    .format(east_asian_line_break, allowed_values)
                )
        self._east_asian_line_break = east_asian_line_break

    @property
    def latin_line_break(self):
        """Gets the latin_line_break of this Paragraph.  # noqa: E501

        True if Latin line break is used with the paragraph.  # noqa: E501

        :return: The latin_line_break of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._latin_line_break

    @latin_line_break.setter
    def latin_line_break(self, latin_line_break):
        """Sets the latin_line_break of this Paragraph.

        True if Latin line break is used with the paragraph.  # noqa: E501

        :param latin_line_break: The latin_line_break of this Paragraph.  # noqa: E501
        :type: str
        """
        if latin_line_break is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if latin_line_break.isdigit():
                int_latin_line_break = int(latin_line_break)
                if int_latin_line_break < 0 or int_latin_line_break >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `latin_line_break` ({0}), must be one of {1}"  # noqa: E501
                        .format(latin_line_break, allowed_values)
                    )
                self._latin_line_break = allowed_values[int_latin_line_break]
                return
            if latin_line_break not in allowed_values:
                raise ValueError(
                    "Invalid value for `latin_line_break` ({0}), must be one of {1}"  # noqa: E501
                    .format(latin_line_break, allowed_values)
                )
        self._latin_line_break = latin_line_break

    @property
    def right_to_left(self):
        """Gets the right_to_left of this Paragraph.  # noqa: E501

        True if right to left direction is used with the paragraph.  # noqa: E501

        :return: The right_to_left of this Paragraph.  # noqa: E501
        :rtype: str
        """
        return self._right_to_left

    @right_to_left.setter
    def right_to_left(self, right_to_left):
        """Sets the right_to_left of this Paragraph.

        True if right to left direction is used with the paragraph.  # noqa: E501

        :param right_to_left: The right_to_left of this Paragraph.  # noqa: E501
        :type: str
        """
        if right_to_left is not None:
            allowed_values = ["False", "True", "NotDefined"]  # noqa: E501
            if right_to_left.isdigit():
                int_right_to_left = int(right_to_left)
                if int_right_to_left < 0 or int_right_to_left >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `right_to_left` ({0}), must be one of {1}"  # noqa: E501
                        .format(right_to_left, allowed_values)
                    )
                self._right_to_left = allowed_values[int_right_to_left]
                return
            if right_to_left not in allowed_values:
                raise ValueError(
                    "Invalid value for `right_to_left` ({0}), must be one of {1}"  # noqa: E501
                    .format(right_to_left, allowed_values)
                )
        self._right_to_left = right_to_left

    @property
    def portion_list(self):
        """Gets the portion_list of this Paragraph.  # noqa: E501

        List of portion links.  # noqa: E501

        :return: The portion_list of this Paragraph.  # noqa: E501
        :rtype: list[ResourceUriElement]
        """
        return self._portion_list

    @portion_list.setter
    def portion_list(self, portion_list):
        """Sets the portion_list of this Paragraph.

        List of portion links.  # noqa: E501

        :param portion_list: The portion_list of this Paragraph.  # noqa: E501
        :type: list[ResourceUriElement]
        """
        self._portion_list = portion_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Paragraph):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.shape_base import ShapeBase

class Chart(ShapeBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'shapes': 'ResourceUriElement',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'shape_type': 'str',
        'chart_type': 'str',
        'show_data_labels_over_maximum': 'bool',
        'series': 'list[Series]',
        'categories': 'list[ChartCategory]',
        'title': 'ChartTitle',
        'back_wall': 'ChartWall',
        'side_wall': 'ChartWall',
        'floor': 'ChartWall',
        'legend': 'Legend',
        'axes': 'Axes',
        'plot_area': 'PlotArea'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'shapes': 'shapes',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'shape_type': 'shapeType',
        'chart_type': 'chartType',
        'show_data_labels_over_maximum': 'showDataLabelsOverMaximum',
        'series': 'series',
        'categories': 'categories',
        'title': 'title',
        'back_wall': 'backWall',
        'side_wall': 'sideWall',
        'floor': 'floor',
        'legend': 'legend',
        'axes': 'axes',
        'plot_area': 'plotArea'
    }

    type_determiners = {
        'type': 'Chart',
        'shapeType': 'Chart',
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='Chart', shape_type='Chart', chart_type=None, show_data_labels_over_maximum=None, series=None, categories=None, title=None, back_wall=None, side_wall=None, floor=None, legend=None, axes=None, plot_area=None):  # noqa: E501
        """Chart - a model defined in Swagger"""  # noqa: E501
        super(Chart, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)

        self._chart_type = None
        self._show_data_labels_over_maximum = None
        self._series = None
        self._categories = None
        self._title = None
        self._back_wall = None
        self._side_wall = None
        self._floor = None
        self._legend = None
        self._axes = None
        self._plot_area = None
        self.type: 'Chart'
        self.shape_type: 'Chart'

        self.chart_type = chart_type
        if show_data_labels_over_maximum is not None:
            self.show_data_labels_over_maximum = show_data_labels_over_maximum
        if series is not None:
            self.series = series
        if categories is not None:
            self.categories = categories
        if title is not None:
            self.title = title
        if back_wall is not None:
            self.back_wall = back_wall
        if side_wall is not None:
            self.side_wall = side_wall
        if floor is not None:
            self.floor = floor
        if legend is not None:
            self.legend = legend
        if axes is not None:
            self.axes = axes
        if plot_area is not None:
            self.plot_area = plot_area

    @property
    def chart_type(self):
        """Gets the chart_type of this Chart.  # noqa: E501

        Gets or sets the type of the chart.  # noqa: E501

        :return: The chart_type of this Chart.  # noqa: E501
        :rtype: str
        """
        return self._chart_type

    @chart_type.setter
    def chart_type(self, chart_type):
        """Sets the chart_type of this Chart.

        Gets or sets the type of the chart.  # noqa: E501

        :param chart_type: The chart_type of this Chart.  # noqa: E501
        :type: str
        """
        if chart_type is not None:
            allowed_values = ["ClusteredColumn", "StackedColumn", "PercentsStackedColumn", "ClusteredColumn3D", "StackedColumn3D", "PercentsStackedColumn3D", "Column3D", "ClusteredCylinder", "StackedCylinder", "PercentsStackedCylinder", "Cylinder3D", "ClusteredCone", "StackedCone", "PercentsStackedCone", "Cone3D", "ClusteredPyramid", "StackedPyramid", "PercentsStackedPyramid", "Pyramid3D", "Line", "StackedLine", "PercentsStackedLine", "LineWithMarkers", "StackedLineWithMarkers", "PercentsStackedLineWithMarkers", "Line3D", "Pie", "Pie3D", "PieOfPie", "ExplodedPie", "ExplodedPie3D", "BarOfPie", "PercentsStackedBar", "ClusteredBar3D", "ClusteredBar", "StackedBar", "StackedBar3D", "PercentsStackedBar3D", "ClusteredHorizontalCylinder", "StackedHorizontalCylinder", "PercentsStackedHorizontalCylinder", "ClusteredHorizontalCone", "StackedHorizontalCone", "PercentsStackedHorizontalCone", "ClusteredHorizontalPyramid", "StackedHorizontalPyramid", "PercentsStackedHorizontalPyramid", "Area", "StackedArea", "PercentsStackedArea", "Area3D", "StackedArea3D", "PercentsStackedArea3D", "ScatterWithMarkers", "ScatterWithSmoothLinesAndMarkers", "ScatterWithSmoothLines", "ScatterWithStraightLinesAndMarkers", "ScatterWithStraightLines", "HighLowClose", "OpenHighLowClose", "VolumeHighLowClose", "VolumeOpenHighLowClose", "Surface3D", "WireframeSurface3D", "Contour", "WireframeContour", "Doughnut", "ExplodedDoughnut", "Bubble", "BubbleWith3D", "Radar", "RadarWithMarkers", "FilledRadar", "SeriesOfMixedTypes", "Treemap", "Sunburst", "Histogram", "ParetoLine", "BoxAndWhisker", "Waterfall", "Funnel"]  # noqa: E501
            if chart_type.isdigit():
                int_chart_type = int(chart_type)
                if int_chart_type < 0 or int_chart_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `chart_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(chart_type, allowed_values)
                    )
                self._chart_type = allowed_values[int_chart_type]
                return
            if chart_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `chart_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(chart_type, allowed_values)
                )
        self._chart_type = chart_type

    @property
    def show_data_labels_over_maximum(self):
        """Gets the show_data_labels_over_maximum of this Chart.  # noqa: E501

        True if data labels over the maximum of the chart shall be shown.  # noqa: E501

        :return: The show_data_labels_over_maximum of this Chart.  # noqa: E501
        :rtype: bool
        """
        return self._show_data_labels_over_maximum

    @show_data_labels_over_maximum.setter
    def show_data_labels_over_maximum(self, show_data_labels_over_maximum):
        """Sets the show_data_labels_over_maximum of this Chart.

        True if data labels over the maximum of the chart shall be shown.  # noqa: E501

        :param show_data_labels_over_maximum: The show_data_labels_over_maximum of this Chart.  # noqa: E501
        :type: bool
        """
        self._show_data_labels_over_maximum = show_data_labels_over_maximum

    @property
    def series(self):
        """Gets the series of this Chart.  # noqa: E501

        Gets or sets the series of chart data values.  # noqa: E501

        :return: The series of this Chart.  # noqa: E501
        :rtype: list[Series]
        """
        return self._series

    @series.setter
    def series(self, series):
        """Sets the series of this Chart.

        Gets or sets the series of chart data values.  # noqa: E501

        :param series: The series of this Chart.  # noqa: E501
        :type: list[Series]
        """
        self._series = series

    @property
    def categories(self):
        """Gets the categories of this Chart.  # noqa: E501

        Gets or sets the categories for chart data  # noqa: E501

        :return: The categories of this Chart.  # noqa: E501
        :rtype: list[ChartCategory]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this Chart.

        Gets or sets the categories for chart data  # noqa: E501

        :param categories: The categories of this Chart.  # noqa: E501
        :type: list[ChartCategory]
        """
        self._categories = categories

    @property
    def title(self):
        """Gets the title of this Chart.  # noqa: E501

        Gets or sets the title.  # noqa: E501

        :return: The title of this Chart.  # noqa: E501
        :rtype: ChartTitle
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Chart.

        Gets or sets the title.  # noqa: E501

        :param title: The title of this Chart.  # noqa: E501
        :type: ChartTitle
        """
        self._title = title

    @property
    def back_wall(self):
        """Gets the back_wall of this Chart.  # noqa: E501

        Gets or sets the back wall.  # noqa: E501

        :return: The back_wall of this Chart.  # noqa: E501
        :rtype: ChartWall
        """
        return self._back_wall

    @back_wall.setter
    def back_wall(self, back_wall):
        """Sets the back_wall of this Chart.

        Gets or sets the back wall.  # noqa: E501

        :param back_wall: The back_wall of this Chart.  # noqa: E501
        :type: ChartWall
        """
        self._back_wall = back_wall

    @property
    def side_wall(self):
        """Gets the side_wall of this Chart.  # noqa: E501

        Gets or sets the side wall.  # noqa: E501

        :return: The side_wall of this Chart.  # noqa: E501
        :rtype: ChartWall
        """
        return self._side_wall

    @side_wall.setter
    def side_wall(self, side_wall):
        """Sets the side_wall of this Chart.

        Gets or sets the side wall.  # noqa: E501

        :param side_wall: The side_wall of this Chart.  # noqa: E501
        :type: ChartWall
        """
        self._side_wall = side_wall

    @property
    def floor(self):
        """Gets the floor of this Chart.  # noqa: E501

        Gets or sets the floor.  # noqa: E501

        :return: The floor of this Chart.  # noqa: E501
        :rtype: ChartWall
        """
        return self._floor

    @floor.setter
    def floor(self, floor):
        """Sets the floor of this Chart.

        Gets or sets the floor.  # noqa: E501

        :param floor: The floor of this Chart.  # noqa: E501
        :type: ChartWall
        """
        self._floor = floor

    @property
    def legend(self):
        """Gets the legend of this Chart.  # noqa: E501

        Gets or sets the legend.  # noqa: E501

        :return: The legend of this Chart.  # noqa: E501
        :rtype: Legend
        """
        return self._legend

    @legend.setter
    def legend(self, legend):
        """Sets the legend of this Chart.

        Gets or sets the legend.  # noqa: E501

        :param legend: The legend of this Chart.  # noqa: E501
        :type: Legend
        """
        self._legend = legend

    @property
    def axes(self):
        """Gets the axes of this Chart.  # noqa: E501

        Gets or sets the axes.  # noqa: E501

        :return: The axes of this Chart.  # noqa: E501
        :rtype: Axes
        """
        return self._axes

    @axes.setter
    def axes(self, axes):
        """Sets the axes of this Chart.

        Gets or sets the axes.  # noqa: E501

        :param axes: The axes of this Chart.  # noqa: E501
        :type: Axes
        """
        self._axes = axes

    @property
    def plot_area(self):
        """Gets the plot_area of this Chart.  # noqa: E501

        Gets or sets the plot area.  # noqa: E501

        :return: The plot_area of this Chart.  # noqa: E501
        :rtype: PlotArea
        """
        return self._plot_area

    @plot_area.setter
    def plot_area(self, plot_area):
        """Sets the plot_area of this Chart.

        Gets or sets the plot area.  # noqa: E501

        :param plot_area: The plot_area of this Chart.  # noqa: E501
        :type: PlotArea
        """
        self._plot_area = plot_area

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Chart):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.task import Task

class ReplaceText(Task):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'old_text': 'str',
        'new_text': 'str',
        'ignore_case': 'bool',
        'slide_position': 'int'
    }

    attribute_map = {
        'type': 'type',
        'old_text': 'oldText',
        'new_text': 'newText',
        'ignore_case': 'ignoreCase',
        'slide_position': 'slidePosition'
    }

    type_determiners = {
        'type': 'ReplaceText',
    }

    def __init__(self, type='ReplaceText', old_text=None, new_text=None, ignore_case=None, slide_position=None):  # noqa: E501
        """ReplaceText - a model defined in Swagger"""  # noqa: E501
        super(ReplaceText, self).__init__(type)

        self._old_text = None
        self._new_text = None
        self._ignore_case = None
        self._slide_position = None
        self.type: 'ReplaceText'

        if old_text is not None:
            self.old_text = old_text
        if new_text is not None:
            self.new_text = new_text
        self.ignore_case = ignore_case
        self.slide_position = slide_position

    @property
    def old_text(self):
        """Gets the old_text of this ReplaceText.  # noqa: E501

        Text to be replaced.  # noqa: E501

        :return: The old_text of this ReplaceText.  # noqa: E501
        :rtype: str
        """
        return self._old_text

    @old_text.setter
    def old_text(self, old_text):
        """Sets the old_text of this ReplaceText.

        Text to be replaced.  # noqa: E501

        :param old_text: The old_text of this ReplaceText.  # noqa: E501
        :type: str
        """
        self._old_text = old_text

    @property
    def new_text(self):
        """Gets the new_text of this ReplaceText.  # noqa: E501

        Text to replace with.  # noqa: E501

        :return: The new_text of this ReplaceText.  # noqa: E501
        :rtype: str
        """
        return self._new_text

    @new_text.setter
    def new_text(self, new_text):
        """Sets the new_text of this ReplaceText.

        Text to replace with.  # noqa: E501

        :param new_text: The new_text of this ReplaceText.  # noqa: E501
        :type: str
        """
        self._new_text = new_text

    @property
    def ignore_case(self):
        """Gets the ignore_case of this ReplaceText.  # noqa: E501

        True to ignore case in replace pattern search.  # noqa: E501

        :return: The ignore_case of this ReplaceText.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_case

    @ignore_case.setter
    def ignore_case(self, ignore_case):
        """Sets the ignore_case of this ReplaceText.

        True to ignore case in replace pattern search.  # noqa: E501

        :param ignore_case: The ignore_case of this ReplaceText.  # noqa: E501
        :type: bool
        """
        self._ignore_case = ignore_case

    @property
    def slide_position(self):
        """Gets the slide_position of this ReplaceText.  # noqa: E501

        One-based position of the slide to perform the replace in. 0 to make the replace throughout the presentation.  # noqa: E501

        :return: The slide_position of this ReplaceText.  # noqa: E501
        :rtype: int
        """
        return self._slide_position

    @slide_position.setter
    def slide_position(self, slide_position):
        """Sets the slide_position of this ReplaceText.

        One-based position of the slide to perform the replace in. 0 to make the replace throughout the presentation.  # noqa: E501

        :param slide_position: The slide_position of this ReplaceText.  # noqa: E501
        :type: int
        """
        self._slide_position = slide_position

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReplaceText):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.shape_base import ShapeBase

class GeometryShape(ShapeBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'shapes': 'ResourceUriElement',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'shape_type': 'str',
        'geometry_shape_type': 'str'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'shapes': 'shapes',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'shape_type': 'shapeType',
        'geometry_shape_type': 'geometryShapeType'
    }

    type_determiners = {
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type=None, shape_type=None, geometry_shape_type=None):  # noqa: E501
        """GeometryShape - a model defined in Swagger"""  # noqa: E501
        super(GeometryShape, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)

        self._geometry_shape_type = None

        self.geometry_shape_type = geometry_shape_type

    @property
    def geometry_shape_type(self):
        """Gets the geometry_shape_type of this GeometryShape.  # noqa: E501

        Geometry shape type.  # noqa: E501

        :return: The geometry_shape_type of this GeometryShape.  # noqa: E501
        :rtype: str
        """
        return self._geometry_shape_type

    @geometry_shape_type.setter
    def geometry_shape_type(self, geometry_shape_type):
        """Sets the geometry_shape_type of this GeometryShape.

        Geometry shape type.  # noqa: E501

        :param geometry_shape_type: The geometry_shape_type of this GeometryShape.  # noqa: E501
        :type: str
        """
        if geometry_shape_type is not None:
            allowed_values = ["Custom", "Line", "LineInverse", "Triangle", "RightTriangle", "Rectangle", "Diamond", "Parallelogram", "Trapezoid", "NonIsoscelesTrapezoid", "Pentagon", "Hexagon", "Heptagon", "Octagon", "Decagon", "Dodecagon", "FourPointedStar", "FivePointedStar", "SixPointedStar", "SevenPointedStar", "EightPointedStar", "TenPointedStar", "TwelvePointedStar", "SixteenPointedStar", "TwentyFourPointedStar", "ThirtyTwoPointedStar", "RoundCornerRectangle", "OneRoundCornerRectangle", "TwoSamesideRoundCornerRectangle", "TwoDiagonalRoundCornerRectangle", "OneSnipOneRoundCornerRectangle", "OneSnipCornerRectangle", "TwoSamesideSnipCornerRectangle", "TwoDiagonalSnipCornerRectangle", "Plaque", "Ellipse", "Teardrop", "HomePlate", "Chevron", "PieWedge", "Pie", "BlockArc", "Donut", "NoSmoking", "RightArrow", "LeftArrow", "UpArrow", "DownArrow", "StripedRightArrow", "NotchedRightArrow", "BentUpArrow", "LeftRightArrow", "UpDownArrow", "LeftUpArrow", "LeftRightUpArrow", "QuadArrow", "CalloutLeftArrow", "CalloutRightArrow", "CalloutUpArrow", "CalloutDownArrow", "CalloutLeftRightArrow", "CalloutUpDownArrow", "CalloutQuadArrow", "BentArrow", "UTurnArrow", "CircularArrow", "LeftCircularArrow", "LeftRightCircularArrow", "CurvedRightArrow", "CurvedLeftArrow", "CurvedUpArrow", "CurvedDownArrow", "SwooshArrow", "Cube", "Can", "LightningBolt", "Heart", "Sun", "Moon", "SmileyFace", "IrregularSeal1", "IrregularSeal2", "FoldedCorner", "Bevel", "Frame", "HalfFrame", "Corner", "DiagonalStripe", "Chord", "CurvedArc", "LeftBracket", "RightBracket", "LeftBrace", "RightBrace", "BracketPair", "BracePair", "StraightConnector1", "BentConnector2", "BentConnector3", "BentConnector4", "BentConnector5", "CurvedConnector2", "CurvedConnector3", "CurvedConnector4", "CurvedConnector5", "Callout1", "Callout2", "Callout3", "Callout1WithAccent", "Callout2WithAccent", "Callout3WithAccent", "Callout1WithBorder", "Callout2WithBorder", "Callout3WithBorder", "Callout1WithBorderAndAccent", "Callout2WithBorderAndAccent", "Callout3WithBorderAndAccent", "CalloutWedgeRectangle", "CalloutWedgeRoundRectangle", "CalloutWedgeEllipse", "CalloutCloud", "Cloud", "Ribbon", "Ribbon2", "EllipseRibbon", "EllipseRibbon2", "LeftRightRibbon", "VerticalScroll", "HorizontalScroll", "Wave", "DoubleWave", "Plus", "ProcessFlow", "DecisionFlow", "InputOutputFlow", "PredefinedProcessFlow", "InternalStorageFlow", "DocumentFlow", "MultiDocumentFlow", "TerminatorFlow", "PreparationFlow", "ManualInputFlow", "ManualOperationFlow", "ConnectorFlow", "PunchedCardFlow", "PunchedTapeFlow", "SummingJunctionFlow", "OrFlow", "CollateFlow", "SortFlow", "ExtractFlow", "MergeFlow", "OfflineStorageFlow", "OnlineStorageFlow", "MagneticTapeFlow", "MagneticDiskFlow", "MagneticDrumFlow", "DisplayFlow", "DelayFlow", "AlternateProcessFlow", "OffPageConnectorFlow", "BlankButton", "HomeButton", "HelpButton", "InformationButton", "ForwardOrNextButton", "BackOrPreviousButton", "EndButton", "BeginningButton", "ReturnButton", "DocumentButton", "SoundButton", "MovieButton", "Gear6", "Gear9", "Funnel", "PlusMath", "MinusMath", "MultiplyMath", "DivideMath", "EqualMath", "NotEqualMath", "CornerTabs", "SquareTabs", "PlaqueTabs", "ChartX", "ChartStar", "ChartPlus", "NotDefined"]  # noqa: E501
            if geometry_shape_type.isdigit():
                int_geometry_shape_type = int(geometry_shape_type)
                if int_geometry_shape_type < 0 or int_geometry_shape_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `geometry_shape_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(geometry_shape_type, allowed_values)
                    )
                self._geometry_shape_type = allowed_values[int_geometry_shape_type]
                return
            if geometry_shape_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `geometry_shape_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(geometry_shape_type, allowed_values)
                )
        self._geometry_shape_type = geometry_shape_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeometryShape):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
from __future__ import absolute_import

import os
import re
import inspect
import json
import logging
import mimetypes
import sys
import tempfile
import traceback
from multiprocessing.pool import ThreadPool

from datetime import date, datetime

# python 2 and python 3 compatibility library
from six import PY3, integer_types, iteritems, text_type
from six.moves.urllib.parse import quote

from asposeslidescloud import models
from asposeslidescloud.configuration import Configuration
from asposeslidescloud import oauth_response
from asposeslidescloud import error_message
from asposeslidescloud.rest import ApiException, RESTClientObject

class ApiClient(object):

    PRIMITIVE_TYPES = (float, bool, bytes, text_type) + integer_types
    NATIVE_TYPES_MAPPING = {
        'int': int,
        'long': int if PY3 else long,
        'float': float,
        'str': str,
        'bool': bool,
        'date': date,
        'datetime': datetime,
        'object': object,
        "ErrorMessage": getattr(error_message, "ErrorMessage")
    }

    def __init__(self, configuration=None):
        if configuration is None:
            configuration = Configuration()
        self.configuration = configuration

        self.pool = ThreadPool()
        self.rest_client = RESTClientObject(configuration)
        self.default_headers = {'x-aspose-client': 'python sdk', 'x-aspose-version': '20.4.0'}
        if configuration.timeout:
            self.default_headers['x-aspose-timeout'] = configuration.timeout
        self.default_headers.update(configuration.custom_headers)

    def __del__(self):
        self.pool.close()
        self.pool.join()

    def __call_api(self, resource_path, method,
                   path_params=None, query_params=None, header_params=None,
                   body=None, post_params=None, files=None,
                   response_type=None, auth_settings=None,
                   _return_http_data_only=None, collection_formats=None, _preload_content=True,
                   _request_timeout=None):
        config = self.configuration

        # header parameters
        header_params = header_params or {}
        header_params.update(self.default_headers)
        if header_params:
            header_params = self.sanitize_for_serialization(header_params)
            header_params = dict(self.parameters_to_tuples(header_params,
                                                           collection_formats))

        # path parameters
        if path_params:
            path_params = self.sanitize_for_serialization(path_params)
            path_params = self.parameters_to_tuples(path_params,
                                                    collection_formats)
            for k, v in path_params:
                if not v:
                    resource_path = resource_path.replace('/{%s}' % k, '')
                else:
                    # specified safe chars, encode everything
                    resource_path = resource_path.replace('{%s}' % k, quote(str(v), safe=config.safe_chars_for_path_param))

        # query parameters
        if query_params:
            query_params = self.sanitize_for_serialization(query_params)
            query_params = self.parameters_to_tuples(query_params, collection_formats)

        # post parameters
        if post_params or files:
            post_params = self.sanitize_for_serialization(post_params)
            post_params = self.parameters_to_tuples(post_params, collection_formats)

        self.__authenticate(header_params, _request_timeout)

        # body
        if body:
            body = self.sanitize_for_serialization(body)

        # request url
        url = self.configuration.host + resource_path

        # perform request and return response
        response_data = self.__call_api_with_refresh(
            method, url, query_params, header_params, post_params, body, files, _preload_content, _request_timeout)

        self.last_response = response_data

        return_data = response_data
        if _preload_content:
            # deserialize response data
            if response_type:
                return_data = self.deserialize(response_data, response_type)
            else:
                return_data = None

        if _return_http_data_only:
            return (return_data)
        else:
            return (return_data, response_data.status, response_data.getheaders())

    def __call_api_with_refresh(self, method, url, query_params, header_params, post_params, body, files, _preload_content, _request_timeout):
        try:
            try:
                return self.request(method, url,
                                     query_params=query_params,
                                     headers=header_params,
                                     post_params=post_params, body = body, files = files,
                                     _preload_content=_preload_content,
                                     _request_timeout=_request_timeout)
            except ApiException as ex:
                if ex.status == 401:
                    self.configuration.access_token = None
                    self.__authenticate(header_params, _request_timeout)
                    return self.request(method, url,
                                     query_params=query_params,
                                     headers=header_params,
                                     post_params=post_params, body = body, files = files,
                                     _preload_content=_preload_content,
                                     _request_timeout=_request_timeout)
                raise ex
        except ApiException as ex:
            if ex.body:
                message = self.deserialize_model(json.loads(ex.body), "ErrorMessage")
                self.__set_exception_message(ex, message)
            raise ex

    def __set_exception_message(self, ex, message):
        if message:
            if message.error:
                self.__set_exception_message(ex, message.error)
            elif message.message:
                ex.body = message.message

    def __authenticate(self, header_params, _request_timeout):
        if not self.configuration.access_token:
            post_params = {
                'grant_type': 'client_credentials',
                'client_id': self.configuration.app_sid,
                'client_secret': self.configuration.app_key
            }
            config = self.configuration
            token_response = self.request(
                'POST', config.auth_base_url + "/connect/token", post_params=post_params, _request_timeout=_request_timeout)
            token_data = json.loads(token_response.data)
            token_klass = getattr(oauth_response, "OAuthResponse")
            token = self.__deserialize_model(token_data, token_klass)
            config.access_token = token.access_token
        header_params["Authorization"] = "Bearer " + self.configuration.access_token

    def sanitize_for_serialization(self, obj):
        """
        Builds a JSON POST object.

        If obj is None, return None.
        If obj is str, int, long, float, bool, return directly.
        If obj is datetime.datetime, datetime.date
            convert to string in iso8601 format.
        If obj is list, sanitize each element in the list.
        If obj is dict, return the dict.
        If obj is swagger model, return the properties dict.

        :param obj: The data to serialize.
        :return: The serialized form of data.
        """
        if obj is None:
            return None
        if isinstance(obj, self.PRIMITIVE_TYPES):
            return obj
        if isinstance(obj, list):
            return [self.sanitize_for_serialization(sub_obj)
                    for sub_obj in obj]
        if isinstance(obj, tuple):
            return tuple(self.sanitize_for_serialization(sub_obj)
                         for sub_obj in obj)
        if isinstance(obj, (datetime, date)):
            return obj.isoformat()

        if isinstance(obj, dict):
            obj_dict = obj
        else:
            # Convert model obj to dict except
            # attributes `swagger_types`, `attribute_map`
            # and attributes which value is not None.
            # Convert attribute name to json key in
            # model definition for request.
            obj_dict = {obj.attribute_map[attr]: getattr(obj, attr)
                        for attr, _ in iteritems(obj.swagger_types)
                        if getattr(obj, attr) is not None}

        return {key: self.sanitize_for_serialization(val)
                for key, val in iteritems(obj_dict)}

    def deserialize(self, response, response_type):
        """
        Deserializes response into an object.

        :param response: RESTResponse object to be deserialized.
        :param response_type: class literal for
            deserialized object, or string of class name.

        :return: deserialized object.
        """
        # handle file downloading
        # save response body into a tmp file and return the instance
        if response_type == "file":
            return self.__deserialize_file(response)

        # fetch data from response object
        try:
            data = json.loads(response.data)
        except ValueError:
            data = response.data

        return self.deserialize_model(data, response_type)

    def deserialize_model(self, data, klass):
        """
        Deserializes dict, list, str into an object.

        :param data: dict, list or str.
        :param klass: class literal, or string of class name.

        :return: object.
        """
        if data is None:
            return None

        if type(klass) == str:
            if klass.startswith('list['):
                sub_kls = re.match('list\[(.*)\]', klass).group(1)
                return [self.deserialize_model(sub_data, sub_kls)
                        for sub_data in data]

            if klass.startswith('dict('):
                sub_kls = re.match('dict\(([^,]*), (.*)\)', klass).group(2)
                return {k: self.deserialize_model(v, sub_kls)
                        for k, v in iteritems(data)}

            # convert str to class
            if klass in self.NATIVE_TYPES_MAPPING:
                klass = self.NATIVE_TYPES_MAPPING[klass]
            else:
                klass = self.__get_class(data, klass)

        if klass in self.PRIMITIVE_TYPES:
            return self.__deserialize_primitive(data, klass)
        elif klass == object:
            return self.__deserialize_object(data)
        elif klass == date:
            return self.__deserialize_date(data)
        elif klass == datetime:
            return self.__deserialize_datatime(data)
        else:
            return self.__deserialize_model(data, klass)

    def call_api(self, resource_path, method,
                 path_params=None, query_params=None, header_params=None,
                 body=None, post_params=None, files=None,
                 response_type=None, auth_settings=None, is_async=None,
                 _return_http_data_only=None, collection_formats=None, _preload_content=True,
                 _request_timeout=None):
        """
        Makes the HTTP request (synchronous) and return the deserialized data.
        To make an async request, define a function for callback.

        :param resource_path: Path to method endpoint.
        :param method: Method to call.
        :param path_params: Path parameters in the url.
        :param query_params: Query parameters in the url.
        :param header_params: Header parameters to be
            placed in the request header.
        :param body: Request body.
        :param post_params dict: Request post form parameters,
            for `application/x-www-form-urlencoded`, `multipart/form-data`.
        :param auth_settings list: Auth Settings names for the request.
        :param response: Response data type.
        :param files dict: key -> filename, value -> filepath,
            for `multipart/form-data`.
        :param is_async bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code and headers
        :param collection_formats: dict of collection formats for path, query,
            header, and post parameters.
        :param _preload_content: if False, the urllib3.HTTPResponse object will be returned without
                                 reading/decoding response data. Default is True.
        :param _request_timeout: timeout setting for this request. If one number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of (connection, read) timeouts.
        :return:
            If provide parameter callback,
            the request will be called asynchronously.
            The method will return the request thread.
            If parameter callback is None,
            then the method will return the response directly.
        """
        if not is_async:
            return self.__call_api(resource_path, method,
                                   path_params, query_params, header_params,
                                   body, post_params, files,
                                   response_type, auth_settings,
                                   _return_http_data_only, collection_formats, _preload_content, _request_timeout)
        else:
            thread = self.pool.apply_async(self.__call_api, (resource_path, method,
                                           path_params, query_params,
                                           header_params, body,
                                           post_params, files,
                                           response_type, auth_settings,
                                           _return_http_data_only,
                                           collection_formats, _preload_content, _request_timeout))
        return thread

    def request(self, method, url, query_params=None, headers=None,
                post_params=None, body=None, files=None, _preload_content=True, _request_timeout=None):
        """
        Makes the HTTP request using RESTClient.
        """
        if method == "GET":
            return self.rest_client.GET(url,
                                        query_params=query_params,
                                        _preload_content=_preload_content,
                                        _request_timeout=_request_timeout,
                                        headers=headers)
        elif method == "HEAD":
            return self.rest_client.HEAD(url,
                                         query_params=query_params,
                                         _preload_content=_preload_content,
                                         _request_timeout=_request_timeout,
                                         headers=headers)
        elif method == "OPTIONS":
            return self.rest_client.OPTIONS(url,
                                            query_params=query_params,
                                            headers=headers,
                                            post_params=post_params,
                                            files=files,
                                            _preload_content=_preload_content,
                                            _request_timeout=_request_timeout,
                                            body=body)
        elif method == "POST":
            return self.rest_client.POST(url,
                                         query_params=query_params,
                                         headers=headers,
                                         post_params=post_params,
                                         files=files,
                                         _preload_content=_preload_content,
                                         _request_timeout=_request_timeout,
                                         body=body)
        elif method == "PUT":
            return self.rest_client.PUT(url,
                                        query_params=query_params,
                                        headers=headers,
                                        post_params=post_params,
                                        files=files,
                                        _preload_content=_preload_content,
                                        _request_timeout=_request_timeout,
                                        body=body)
        elif method == "PATCH":
            return self.rest_client.PATCH(url,
                                          query_params=query_params,
                                          headers=headers,
                                          post_params=post_params,
                                          files=files,
                                          _preload_content=_preload_content,
                                          _request_timeout=_request_timeout,
                                          body=body)
        elif method == "DELETE":
            return self.rest_client.DELETE(url,
                                           query_params=query_params,
                                           headers=headers,
                                           _preload_content=_preload_content,
                                           _request_timeout=_request_timeout,
                                           body=body)
        else:
            raise ValueError(
                "http method must be `GET`, `HEAD`, `OPTIONS`,"
                " `POST`, `PATCH`, `PUT` or `DELETE`."
            )

    def parameters_to_tuples(self, params, collection_formats):
        """
        Get parameters as list of tuples, formatting collections.

        :param params: Parameters as dict or list of two-tuples
        :param dict collection_formats: Parameter collection formats
        :return: Parameters as list of tuples, collections formatted
        """
        new_params = []
        if collection_formats is None:
            collection_formats = {}
        for k, v in iteritems(params) if isinstance(params, dict) else params:
            if k in collection_formats:
                collection_format = collection_formats[k]
                if collection_format == 'multi':
                    new_params.extend((k, value) for value in v)
                else:
                    if collection_format == 'ssv':
                        delimiter = ' '
                    elif collection_format == 'tsv':
                        delimiter = '\t'
                    elif collection_format == 'pipes':
                        delimiter = '|'
                    else:  # csv is the default
                        delimiter = ','
                    new_params.append(
                        (k, delimiter.join(str(value) for value in v)))
            else:
                new_params.append((k, v))
        return new_params

    def select_header_accept(self, accepts):
        """
        Returns `Accept` based on an array of accepts provided.

        :param accepts: List of headers.
        :return: Accept (e.g. application/json).
        """
        if not accepts:
            return

        accepts = [x.lower() for x in accepts]

        if 'application/json' in accepts:
            return 'application/json'
        else:
            return ', '.join(accepts)

    def select_header_content_type(self, content_types):
        """
        Returns `Content-Type` based on an array of content_types provided.

        :param content_types: List of content-types.
        :return: Content-Type (e.g. application/json).
        """
        if not content_types:
            return 'application/json'

        content_types = [x.lower() for x in content_types]

        if 'application/json' in content_types or '*/*' in content_types:
            return 'application/json'
        else:
            return content_types[0]

    def update_params_for_auth(self, headers, querys, auth_settings):
        """
        Updates header and query params based on authentication setting.

        :param headers: Header parameters dict to be updated.
        :param querys: Query parameters tuple list to be updated.
        :param auth_settings: Authentication setting identifiers list.
        """
        if not auth_settings:
            return

        for auth in auth_settings:
            auth_setting = self.configuration.auth_settings().get(auth)
            if auth_setting:
                if not auth_setting['value']:
                    continue
                elif auth_setting['in'] == 'header':
                    headers[auth_setting['key']] = auth_setting['value']
                elif auth_setting['in'] == 'query':
                    querys.append((auth_setting['key'], auth_setting['value']))
                else:
                    raise ValueError(
                        'Authentication token must be in `query` or `header`'
                    )

    def __deserialize_file(self, response):
        """
        Saves response body into a file in a temporary folder,
        using the filename from the `Content-Disposition` header if provided.

        :param response:  RESTResponse.
        :return: file path.
        """
        fd, path = tempfile.mkstemp(dir=self.configuration.temp_folder_path)
        os.close(fd)
        os.remove(path)

        content_disposition = response.getheader("Content-Disposition")
        if content_disposition:
            filename = re.search(r'filename=[\'"]?([^\'"\s]+)[\'"]?', content_disposition).group(1)
            path = self.__get_file_name(os.path.dirname(path), filename)
        mode = 'w'
        if (isinstance(response.data, bytes)):
            mode = 'wb'
        with open(path, mode) as f:
            f.write(response.data)

        return path

    def __get_file_name(self, dirname, filename):
        """
        Gets a file path for a directory name and a file name and generates an alternative name if a file with such a name already exists.

        :param dirname:  directory name.
        :param filename:  file name.
        :return: file path.
        """
        filenames = os.path.splitext(filename)
        index = 0
        postfix = ""
        while True:
            path = os.path.join(dirname, filenames[0] + postfix + filenames[1])
            if not os.path.exists(path):
                return path
            index += 1
            postfix = "_" + str(index)

    def __deserialize_primitive(self, data, klass):
        """
        Deserializes string to primitive type.

        :param data: str.
        :param klass: class literal.

        :return: int, long, float, str, bool.
        """
        try:
            return klass(data)
        except UnicodeEncodeError:
            return unicode(data)
        except TypeError:
            return data

    def __deserialize_object(self, value):
        """
        Return a original value.

        :return: object.
        """
        return value

    def __deserialize_date(self, string):
        """
        Deserializes string to date.

        :param string: str.
        :return: date.
        """
        try:
            from dateutil.parser import parse
            return parse(string).date()
        except ImportError:
            return string
        except ValueError:
            raise ApiException(
                status=0,
                reason="Failed to parse `{0}` into a date object".format(string)
            )

    def __deserialize_datatime(self, string):
        """
        Deserializes string to datetime.

        The string should be in iso8601 datetime format.

        :param string: str.
        :return: datetime.
        """
        try:
            from dateutil.parser import parse
            return parse(string)
        except ImportError:
            return string
        except ValueError:
            raise ApiException(
                status=0,
                reason=(
                    "Failed to parse `{0}` into a datetime object"
                    .format(string)
                )
            )

    def __get_class(self, data, klass):
        klass = getattr(models, klass)
        for key, obj in inspect.getmembers(models):
            if inspect.isclass(obj) and issubclass(obj, klass) and self.__is_class_suitable(data, obj):
                return obj
        return klass

    def __is_class_suitable(self, data, klass):
        if not hasattr(klass, 'type_determiners') or not len(klass.type_determiners):
            return False
        for key, value in klass.type_determiners.items():
            if not key in data.keys() or not data[key] == value:
                return False
        return True

    def __deserialize_model(self, data, klass):
        """
        Deserializes list or dict to model.

        :param data: dict, list.
        :param klass: class literal.
        :return: model object.
        """
        if not klass.swagger_types:
            return data

        kwargs = {}
        self.__fill_model_args(kwargs, data, klass)
        return klass(**kwargs)

    def __fill_model_args(self, args, data, klass):
        """
        Fills list of attribures for class.

        :param args: attribute list.
        :param data: dict, list.
        :param klass: class literal.
        """
        if klass.swagger_types is not None:
            for attr, attr_type in iteritems(klass.swagger_types):
                if data is not None and isinstance(data, (list, dict)):
                    if klass.attribute_map[attr] in data:
                        value = data[klass.attribute_map[attr]]
                        args[attr] = self.deserialize_model(value, attr_type)
                    else:
                        attr_upper = klass.attribute_map[attr][0].upper() + klass.attribute_map[attr][1:]
                        if attr_upper in data:
                            value = data[attr_upper]
                            args[attr] = self.deserialize_model(value, attr_type)
            base_klass = klass.__bases__[0]
            if not base_klass == object:
                self.__fill_model_args(args, data, base_klass)



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.task import Task

class Save(Task):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'format': 'str',
        'output': 'OutputFile',
        'options': 'ExportOptions'
    }

    attribute_map = {
        'type': 'type',
        'format': 'format',
        'output': 'output',
        'options': 'options'
    }

    type_determiners = {
        'type': 'Save',
    }

    def __init__(self, type='Save', format=None, output=None, options=None):  # noqa: E501
        """Save - a model defined in Swagger"""  # noqa: E501
        super(Save, self).__init__(type)

        self._format = None
        self._output = None
        self._options = None
        self.type: 'Save'

        self.format = format
        if output is not None:
            self.output = output
        if options is not None:
            self.options = options

    @property
    def format(self):
        """Gets the format of this Save.  # noqa: E501

        Format.  # noqa: E501

        :return: The format of this Save.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Save.

        Format.  # noqa: E501

        :param format: The format of this Save.  # noqa: E501
        :type: str
        """
        if format is not None:
            allowed_values = ["Pdf", "Xps", "Tiff", "Pptx", "Odp", "Otp", "Ppt", "Pps", "Ppsx", "Pptm", "Ppsm", "Pot", "Potx", "Potm", "Html", "Swf", "Svg", "Jpeg", "Png", "Gif", "Bmp"]  # noqa: E501
            if format.isdigit():
                int_format = int(format)
                if int_format < 0 or int_format >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                        .format(format, allowed_values)
                    )
                self._format = allowed_values[int_format]
                return
            if format not in allowed_values:
                raise ValueError(
                    "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                    .format(format, allowed_values)
                )
        self._format = format

    @property
    def output(self):
        """Gets the output of this Save.  # noqa: E501

        Output file.  # noqa: E501

        :return: The output of this Save.  # noqa: E501
        :rtype: OutputFile
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this Save.

        Output file.  # noqa: E501

        :param output: The output of this Save.  # noqa: E501
        :type: OutputFile
        """
        self._output = output

    @property
    def options(self):
        """Gets the options of this Save.  # noqa: E501

        Save options.  # noqa: E501

        :return: The options of this Save.  # noqa: E501
        :rtype: ExportOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this Save.

        Save options.  # noqa: E501

        :param options: The options of this Save.  # noqa: E501
        :type: ExportOptions
        """
        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Save):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class Effect(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'subtype': 'str',
        'preset_class_type': 'str',
        'shape_index': 'int',
        'trigger_type': 'str',
        'accelerate': 'float',
        'auto_reverse': 'bool',
        'decelerate': 'float',
        'duration': 'float',
        'repeat_count': 'float',
        'repeat_duration': 'float',
        'restart': 'str',
        'speed': 'float',
        'trigger_delay_time': 'float'
    }

    attribute_map = {
        'type': 'type',
        'subtype': 'subtype',
        'preset_class_type': 'presetClassType',
        'shape_index': 'shapeIndex',
        'trigger_type': 'triggerType',
        'accelerate': 'accelerate',
        'auto_reverse': 'autoReverse',
        'decelerate': 'decelerate',
        'duration': 'duration',
        'repeat_count': 'repeatCount',
        'repeat_duration': 'repeatDuration',
        'restart': 'restart',
        'speed': 'speed',
        'trigger_delay_time': 'triggerDelayTime'
    }

    type_determiners = {
    }

    def __init__(self, type=None, subtype=None, preset_class_type=None, shape_index=None, trigger_type=None, accelerate=None, auto_reverse=None, decelerate=None, duration=None, repeat_count=None, repeat_duration=None, restart=None, speed=None, trigger_delay_time=None):  # noqa: E501
        """Effect - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._subtype = None
        self._preset_class_type = None
        self._shape_index = None
        self._trigger_type = None
        self._accelerate = None
        self._auto_reverse = None
        self._decelerate = None
        self._duration = None
        self._repeat_count = None
        self._repeat_duration = None
        self._restart = None
        self._speed = None
        self._trigger_delay_time = None

        if type is not None:
            self.type = type
        if subtype is not None:
            self.subtype = subtype
        if preset_class_type is not None:
            self.preset_class_type = preset_class_type
        self.shape_index = shape_index
        if trigger_type is not None:
            self.trigger_type = trigger_type
        if accelerate is not None:
            self.accelerate = accelerate
        if auto_reverse is not None:
            self.auto_reverse = auto_reverse
        if decelerate is not None:
            self.decelerate = decelerate
        if duration is not None:
            self.duration = duration
        if repeat_count is not None:
            self.repeat_count = repeat_count
        if repeat_duration is not None:
            self.repeat_duration = repeat_duration
        if restart is not None:
            self.restart = restart
        if speed is not None:
            self.speed = speed
        if trigger_delay_time is not None:
            self.trigger_delay_time = trigger_delay_time

    @property
    def type(self):
        """Gets the type of this Effect.  # noqa: E501

        Effect type.  # noqa: E501

        :return: The type of this Effect.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Effect.

        Effect type.  # noqa: E501

        :param type: The type of this Effect.  # noqa: E501
        :type: str
        """
        if type is not None:
            allowed_values = ["Appear", "CurveUpDown", "Ascend", "Blast", "Blinds", "Blink", "BoldFlash", "BoldReveal", "Boomerang", "Bounce", "Box", "BrushOnColor", "BrushOnUnderline", "CenterRevolve", "ChangeFillColor", "ChangeFont", "ChangeFontColor", "ChangeFontSize", "ChangeFontStyle", "ChangeLineColor", "Checkerboard", "Circle", "ColorBlend", "ColorTypewriter", "ColorWave", "ComplementaryColor", "ComplementaryColor2", "Compress", "ContrastingColor", "Crawl", "Credits", "Custom", "Darken", "Desaturate", "Descend", "Diamond", "Dissolve", "EaseInOut", "Expand", "Fade", "FadedSwivel", "FadedZoom", "FlashBulb", "FlashOnce", "Flicker", "Flip", "Float", "Fly", "Fold", "Glide", "GrowAndTurn", "GrowShrink", "GrowWithColor", "Lighten", "LightSpeed", "MediaPause", "MediaPlay", "MediaStop", "Path4PointStar", "Path5PointStar", "Path6PointStar", "Path8PointStar", "PathArcDown", "PathArcLeft", "PathArcRight", "PathArcUp", "PathBean", "PathBounceLeft", "PathBounceRight", "PathBuzzsaw", "PathCircle", "PathCrescentMoon", "PathCurvedSquare", "PathCurvedX", "PathCurvyLeft", "PathCurvyRight", "PathCurvyStar", "PathDecayingWave", "PathDiagonalDownRight", "PathDiagonalUpRight", "PathDiamond", "PathDown", "PathEqualTriangle", "PathFigure8Four", "PathFootball", "PathFunnel", "PathHeart", "PathHeartbeat", "PathHexagon", "PathHorizontalFigure8", "PathInvertedSquare", "PathInvertedTriangle", "PathLeft", "PathLoopdeLoop", "PathNeutron", "PathOctagon", "PathParallelogram", "PathPeanut", "PathPentagon", "PathPlus", "PathPointyStar", "PathRight", "PathRightTriangle", "PathSCurve1", "PathSCurve2", "PathSineWave", "PathSpiralLeft", "PathSpiralRight", "PathSpring", "PathSquare", "PathStairsDown", "PathSwoosh", "PathTeardrop", "PathTrapezoid", "PathTurnDown", "PathTurnRight", "PathTurnUp", "PathTurnUpRight", "PathUp", "PathUser", "PathVerticalFigure8", "PathWave", "PathZigzag", "Peek", "Pinwheel", "Plus", "RandomBars", "RandomEffects", "RiseUp", "Shimmer", "Sling", "Spin", "Spinner", "Spiral", "Split", "Stretch", "Strips", "StyleEmphasis", "Swish", "Swivel", "Teeter", "Thread", "Transparency", "Unfold", "VerticalGrow", "Wave", "Wedge", "Wheel", "Whip", "Wipe", "Magnify", "Zoom", "OLEObjectShow", "OLEObjectEdit", "OLEObjectOpen"]  # noqa: E501
            if type.isdigit():
                int_type = int(type)
                if int_type < 0 or int_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                        .format(type, allowed_values)
                    )
                self._type = allowed_values[int_type]
                return
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values)
                )
        self._type = type

    @property
    def subtype(self):
        """Gets the subtype of this Effect.  # noqa: E501

        Effect subtype.  # noqa: E501

        :return: The subtype of this Effect.  # noqa: E501
        :rtype: str
        """
        return self._subtype

    @subtype.setter
    def subtype(self, subtype):
        """Sets the subtype of this Effect.

        Effect subtype.  # noqa: E501

        :param subtype: The subtype of this Effect.  # noqa: E501
        :type: str
        """
        if subtype is not None:
            allowed_values = ["None", "Across", "Bottom", "BottomLeft", "BottomRight", "Center", "Clockwise", "CounterClockwise", "GradualAndCycleClockwise", "GradualAndCycleCounterClockwise", "Down", "DownLeft", "DownRight", "FontAllCaps", "FontBold", "FontItalic", "FontShadow", "FontStrikethrough", "FontUnderline", "Gradual", "Horizontal", "HorizontalIn", "HorizontalOut", "In", "InBottom", "InCenter", "InSlightly", "Instant", "Left", "OrdinalMask", "Out", "OutBottom", "OutCenter", "OutSlightly", "Right", "Slightly", "Top", "TopLeft", "TopRight", "Up", "UpLeft", "UpRight", "Vertical", "VerticalIn", "VerticalOut", "Wheel1", "Wheel2", "Wheel3", "Wheel4", "Wheel8"]  # noqa: E501
            if subtype.isdigit():
                int_subtype = int(subtype)
                if int_subtype < 0 or int_subtype >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `subtype` ({0}), must be one of {1}"  # noqa: E501
                        .format(subtype, allowed_values)
                    )
                self._subtype = allowed_values[int_subtype]
                return
            if subtype not in allowed_values:
                raise ValueError(
                    "Invalid value for `subtype` ({0}), must be one of {1}"  # noqa: E501
                    .format(subtype, allowed_values)
                )
        self._subtype = subtype

    @property
    def preset_class_type(self):
        """Gets the preset_class_type of this Effect.  # noqa: E501

        Preset class type.  # noqa: E501

        :return: The preset_class_type of this Effect.  # noqa: E501
        :rtype: str
        """
        return self._preset_class_type

    @preset_class_type.setter
    def preset_class_type(self, preset_class_type):
        """Sets the preset_class_type of this Effect.

        Preset class type.  # noqa: E501

        :param preset_class_type: The preset_class_type of this Effect.  # noqa: E501
        :type: str
        """
        if preset_class_type is not None:
            allowed_values = ["Entrance", "Exit", "Emphasis", "Path", "MediaCall", "OLEActionVerbs"]  # noqa: E501
            if preset_class_type.isdigit():
                int_preset_class_type = int(preset_class_type)
                if int_preset_class_type < 0 or int_preset_class_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `preset_class_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(preset_class_type, allowed_values)
                    )
                self._preset_class_type = allowed_values[int_preset_class_type]
                return
            if preset_class_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `preset_class_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(preset_class_type, allowed_values)
                )
        self._preset_class_type = preset_class_type

    @property
    def shape_index(self):
        """Gets the shape_index of this Effect.  # noqa: E501

        Shape index.  # noqa: E501

        :return: The shape_index of this Effect.  # noqa: E501
        :rtype: int
        """
        return self._shape_index

    @shape_index.setter
    def shape_index(self, shape_index):
        """Sets the shape_index of this Effect.

        Shape index.  # noqa: E501

        :param shape_index: The shape_index of this Effect.  # noqa: E501
        :type: int
        """
        self._shape_index = shape_index

    @property
    def trigger_type(self):
        """Gets the trigger_type of this Effect.  # noqa: E501

        Effect trigger type.  # noqa: E501

        :return: The trigger_type of this Effect.  # noqa: E501
        :rtype: str
        """
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, trigger_type):
        """Sets the trigger_type of this Effect.

        Effect trigger type.  # noqa: E501

        :param trigger_type: The trigger_type of this Effect.  # noqa: E501
        :type: str
        """
        if trigger_type is not None:
            allowed_values = ["AfterPrevious", "OnClick", "WithPrevious"]  # noqa: E501
            if trigger_type.isdigit():
                int_trigger_type = int(trigger_type)
                if int_trigger_type < 0 or int_trigger_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `trigger_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(trigger_type, allowed_values)
                    )
                self._trigger_type = allowed_values[int_trigger_type]
                return
            if trigger_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `trigger_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(trigger_type, allowed_values)
                )
        self._trigger_type = trigger_type

    @property
    def accelerate(self):
        """Gets the accelerate of this Effect.  # noqa: E501

        The percentage of duration accelerate behavior effect.  # noqa: E501

        :return: The accelerate of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._accelerate

    @accelerate.setter
    def accelerate(self, accelerate):
        """Sets the accelerate of this Effect.

        The percentage of duration accelerate behavior effect.  # noqa: E501

        :param accelerate: The accelerate of this Effect.  # noqa: E501
        :type: float
        """
        self._accelerate = accelerate

    @property
    def auto_reverse(self):
        """Gets the auto_reverse of this Effect.  # noqa: E501

        True to automatically play the animation in reverse after playing it in the forward direction.  # noqa: E501

        :return: The auto_reverse of this Effect.  # noqa: E501
        :rtype: bool
        """
        return self._auto_reverse

    @auto_reverse.setter
    def auto_reverse(self, auto_reverse):
        """Sets the auto_reverse of this Effect.

        True to automatically play the animation in reverse after playing it in the forward direction.  # noqa: E501

        :param auto_reverse: The auto_reverse of this Effect.  # noqa: E501
        :type: bool
        """
        self._auto_reverse = auto_reverse

    @property
    def decelerate(self):
        """Gets the decelerate of this Effect.  # noqa: E501

        The percentage of duration decelerate behavior effect.  # noqa: E501

        :return: The decelerate of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._decelerate

    @decelerate.setter
    def decelerate(self, decelerate):
        """Sets the decelerate of this Effect.

        The percentage of duration decelerate behavior effect.  # noqa: E501

        :param decelerate: The decelerate of this Effect.  # noqa: E501
        :type: float
        """
        self._decelerate = decelerate

    @property
    def duration(self):
        """Gets the duration of this Effect.  # noqa: E501

        The duration of animation effect.  # noqa: E501

        :return: The duration of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Effect.

        The duration of animation effect.  # noqa: E501

        :param duration: The duration of this Effect.  # noqa: E501
        :type: float
        """
        self._duration = duration

    @property
    def repeat_count(self):
        """Gets the repeat_count of this Effect.  # noqa: E501

        The number of times the effect should repeat.  # noqa: E501

        :return: The repeat_count of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._repeat_count

    @repeat_count.setter
    def repeat_count(self, repeat_count):
        """Sets the repeat_count of this Effect.

        The number of times the effect should repeat.  # noqa: E501

        :param repeat_count: The repeat_count of this Effect.  # noqa: E501
        :type: float
        """
        self._repeat_count = repeat_count

    @property
    def repeat_duration(self):
        """Gets the repeat_duration of this Effect.  # noqa: E501

        The number of times the effect should repeat.  # noqa: E501

        :return: The repeat_duration of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._repeat_duration

    @repeat_duration.setter
    def repeat_duration(self, repeat_duration):
        """Sets the repeat_duration of this Effect.

        The number of times the effect should repeat.  # noqa: E501

        :param repeat_duration: The repeat_duration of this Effect.  # noqa: E501
        :type: float
        """
        self._repeat_duration = repeat_duration

    @property
    def restart(self):
        """Gets the restart of this Effect.  # noqa: E501

        The way for a effect to restart after complete.  # noqa: E501

        :return: The restart of this Effect.  # noqa: E501
        :rtype: str
        """
        return self._restart

    @restart.setter
    def restart(self, restart):
        """Sets the restart of this Effect.

        The way for a effect to restart after complete.  # noqa: E501

        :param restart: The restart of this Effect.  # noqa: E501
        :type: str
        """
        if restart is not None:
            allowed_values = ["Always", "WhenNotActive", "Never", "NotDefined"]  # noqa: E501
            if restart.isdigit():
                int_restart = int(restart)
                if int_restart < 0 or int_restart >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `restart` ({0}), must be one of {1}"  # noqa: E501
                        .format(restart, allowed_values)
                    )
                self._restart = allowed_values[int_restart]
                return
            if restart not in allowed_values:
                raise ValueError(
                    "Invalid value for `restart` ({0}), must be one of {1}"  # noqa: E501
                    .format(restart, allowed_values)
                )
        self._restart = restart

    @property
    def speed(self):
        """Gets the speed of this Effect.  # noqa: E501

        The percentage by which to speed up (or slow down) the timing.  # noqa: E501

        :return: The speed of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this Effect.

        The percentage by which to speed up (or slow down) the timing.  # noqa: E501

        :param speed: The speed of this Effect.  # noqa: E501
        :type: float
        """
        self._speed = speed

    @property
    def trigger_delay_time(self):
        """Gets the trigger_delay_time of this Effect.  # noqa: E501

        Delay time after trigger.  # noqa: E501

        :return: The trigger_delay_time of this Effect.  # noqa: E501
        :rtype: float
        """
        return self._trigger_delay_time

    @trigger_delay_time.setter
    def trigger_delay_time(self, trigger_delay_time):
        """Sets the trigger_delay_time of this Effect.

        Delay time after trigger.  # noqa: E501

        :param trigger_delay_time: The trigger_delay_time of this Effect.  # noqa: E501
        :type: float
        """
        self._trigger_delay_time = trigger_delay_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Effect):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
